<?php
/*
Plugin Name: EmergencyWP
Plugin URI: https://emergencyWP.net/
Description: EmergencyWP helps you plan processes for the case of personal emergencies right from your WordPress Dashboard. Pass over information to coworkers or clients automatically if you can't do it manually anymore (e.g. accidants, death, etc.). Plan life checks, setup contacts and messages and more. See our addons for more functionalities.
Version: 1.3.8
Author: EmergencyWP Team, Albert Brückmann
Author URI: https://emergencywp.net/
Update Server: https://emergencyWP.net/
Min WP Version: 1.5
*/

defined('ABSPATH') or die("No script kiddies please!");
// Additional Emergency WP Plugins
define('EMERGENCY_WP_PLUGIN_PATH', 'emergencywp/emergencywp.php');
define('EMERGENCY_WP_PLUGIN_NAME', 'emergencywp');
define('EMERGENCY_WP_VERSION', '1.3.8');
define('EMERGENCY_WP_PLUGIN_URL', plugin_dir_url(__FILE__));
define('EMERGENCY_WP_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('EMERGENCY_WP_FRONTEND_URL', get_site_url());

// Additional Emergency WP Plugins
define('EMERGENCY_WP_TRUSTY_PLUGIN_PATH', 'emergencywp-trustees/emergencywp-trustees.php');
define('EMERGENCY_WP_DELIVERY_CONDITIONS_PLUGIN_PATH', 'emergencywp-delivery-conditions/emergencywp-delivery-conditions.php');

global $emergencywp_options, $emergencywp_beta;
$emergencywp_beta = true;

require_once('lib/class.emergencyWPConfig.php');
require_once('lib/class.EWP_InitPluginVars.php');
require_once('main.functions.php');

if (!function_exists('emergencyWP_plugin_load_plugin_text_domain')) {
    function emergencyWP_plugin_load_plugin_text_domain()
    {
        load_plugin_textdomain('emergencywp', FALSE, basename(dirname(__FILE__)) . '/languages/');
    }
}

add_action('plugins_loaded', 'emergencyWP_plugin_load_plugin_text_domain');
add_action('admin_init', array('emergencyWPAdmin', 'ewp_login_redirect'));
add_action('wp_enqueue_scripts', array('emergencyWPAdmin', 'ewp_header_script'));

/* Runs on plugin activation*/
register_activation_hook(__FILE__, array('emergencyWPActivate', 'load'));
add_action('wpmu_new_blog', array('emergencyWPActivate', 'network_new_blog_load'), 10, 6);

/* Runs on plugin deactivation*/
register_deactivation_hook(__FILE__, array('emergencyWPDeactivate', 'load'));

/* Runs on plugin uninstall*/
register_uninstall_hook(__FILE__, array('emergencyWPUninstall', 'load'));

if (!function_exists('_is_emergencywp_installed')) {

    function _is_emergencywp_installed()
    {
        $file_path = 'emergencywp/emergencywp.php';
        $installed_plugins = get_plugins();

        return isset($installed_plugins[$file_path]);
    }
}
/* Runs if new blog was added */
add_action('wpmu_new_blog', array('emergencyWPActivate', 'load'));

add_action('init', array('emergencyWPAdmin', 'emergencywp_add_user_role'));
add_action('admin_init', array('emergencyWPAdmin', 'emergency_wp_role_remove_menus'));
add_action('admin_init', array('emergencyWPAdmin', 'init'));

add_action('wp_login', array('emergencyWPAdmin', 'login_lifecheck'), 10, 2);
add_action('wp_version_check', array('emergencyWPAdmin', 'verified_notice'));

require_once(EMERGENCY_WP_PLUGIN_DIR . 'lib/EWP_classAutoloader.php');
spl_autoload_register(array('EWP_classAutoloader', 'load'));

if (!function_exists('ewpget')) {
    /**
     * Helper function for getting values from query strings or arrays
     *
     * @param string $name The key
     * @param array $array The array to search through.  If null, checks query strings.  Defaults to null.
     *
     * @return string The value.  If none found, empty string.
     */
    function ewpget($name, $array = null)
    {
        if (!isset($array)) {
            if(isset($_GET)){
                foreach ($_GET AS $key =>$item){
                    $array[sanitize_text_field($key)] = sanitize_text_field($item);
                }
            }
        }

        if (!is_array($array)) {
            return '';
        }

        if (isset($array[$name])) {
            return $array[$name];
        }

        return '';
    }
}


if (!function_exists('ewppost')) {
    /**
     * Helper function to obtain POST values.
     *
     * @param string $name The key
     * @param bool $do_stripslashes Optional. Performs stripslashes_deep.  Defaults to true.
     *
     * @return string The value.  If none found, empty string.
     */
    function ewppost($name, $do_stripslashes = true)
    {
        if (isset($_POST[$name])) {
            return $do_stripslashes ? stripslashes_deep(sanitize_text_field($_POST[$name])) : sanitize_text_field($_POST[$name]);
        }

        return '';
    }
}

add_action('admin_notices', 'emergencywp_admin_notices');


if (!function_exists('emergencywp_admin_notices')) {
    function emergencywp_admin_notices()
    {
        $ewpNotices = ewp_get_option('emergencyWP_notices');
        if (isset($_GET['emergencywp_remove_notice']) && isset($ewpNotices[sanitize_key($_GET['emergencywp_remove_notice'])])) {
            unset($ewpNotices[sanitize_key($_GET['emergencywp_remove_notice'])]);
            do_action('emergencywp_remove_notice', sanitize_key($_GET['emergencywp_remove_notice']));
        }

        if (is_array($ewpNotices)) {
            foreach ($ewpNotices AS $key => $ewpNotice) {
                if ($key == 'licence') {
                    if (isset($_GET['page']) && (sanitize_text_field($_GET['page']) == 'emergencywp' || sanitize_text_field($_GET['page']) == 'emergencywp-licences')) {
                        break;
                    }
                    ?>
                    <div data-id="licence" id="emergencyWP-notice-licence"
                         class="notice emergencyWP-notice notice-error error emergencyWP-notice-dismissable">
                        <strong>
                            <?php echo sprintf(__('Hey! Would you like automatic updates and support? Please %s of EmergencyWP.', 'emergencywp'), '<a href="' . admin_url('admin.php?page=emergencywp-licences') . '">' . esc_html__('activate your copy', 'emergencywp') . '</a>'); ?>
                        </strong>
                        <a class="notice-dismiss"
                           title="<?php echo esc_attr__('Dismiss this notice', 'emergencywp'); ?>"
                           href="<?php echo add_query_arg(array('emergencywp_remove_notice' => 'licence')); ?>">
                            <?php echo esc_attr__('Dismiss', 'emergencywp'); ?>
                            <span class="screen-reader-text"><?php echo esc_attr__('Dismiss this notice ', 'emergencywp'); ?></span>
                        </a>
                    </div>
                    <?php
                }
            }
        }
        if (is_multisite() && !class_exists('EmergencyWPMultiSite')) {
            ?>
            <div data-id="licence" id="emergencyWP-notice-licence"
                 class="notice emergencyWP-notice notice-error error emergencyWP-notice-dismissable">
                <strong>
                    <?php echo __('Hey! You are running a multisite. EmergencyWP will not work properly without the EmergencyWP MultiSite Addon.', 'emergencywp'); ?>
                </strong>
                <a class="notice-dismiss" title="<?php echo esc_attr__('Dismiss this notice', 'emergencywp'); ?>"
                   href="<?php echo add_query_arg(array('emergencywp_remove_notice' => 'licence')); ?>">
                    <?php echo esc_attr__('Dismiss', 'emergencywp'); ?>
                    <span class="screen-reader-text"><?php echo esc_attr__('Dismiss this notice ', 'emergencywp'); ?></span>
                </a>
            </div>
            <?php
        }
    }
}


if (!function_exists('ewp_insert_deactivate_link_id')) {
    function ewp_insert_deactivate_link_id($links)
    {
        if (!is_multisite()) {
            $links['deactivate'] = str_replace('<a', '<a id="emergencywp-plugin-disable-link"', $links['deactivate']);
        }
        return $links;
    }
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'ewp_insert_deactivate_link_id', 10, 2);

/** Start **/
$emergencywp_options = ewp_get_option('emergencywp_options', array(), false);
$cron_secret = emergencywp_option('cron_secret', '', true);
if (empty($cron_secret)) {
    //Defaults
    $cron_secret = md5(uniqid());
    emergencywp_update_option('cron_secret', $cron_secret, true);
}

if (!defined('EMERGENCYWP_CRON_SECRET')) {
    define('EMERGENCYWP_CRON_SECRET', $cron_secret);
}


$isNew = ewp_get_option('emergencywp') == false;

$classes = array('Contacts', 'Cron');

foreach ($classes as $class) {
    require_once EMERGENCY_WP_PLUGIN_DIR . "lib/class.emergencyWP$class.php";
    $classname = 'emergencyWP' . ucwords($class);
    if (class_exists($classname)) {
        $classObj = new $classname();
        if (method_exists($classObj, 'on_activate')) {
            //$classObj->on_activate($isNew);
        }
    }
}

function ewp_query_vars( $qvars ) {
    $qvars[] = 'jobController';
    return $qvars;
}
add_filter( 'query_vars', 'ewp_query_vars' );


add_action( 'template_include', 'ewp_change_template');
function ewp_change_template( $template )
{
    if (get_query_var('jobController', false) !== false) {
        include(EMERGENCY_WP_PLUGIN_DIR.'cron/jobController.php');
    }else{
        return $template;
    }
}

global $emergencyWP;
$emergencyWP = new emergencyWPAdmin();

$emergencyWP->getSystemGmtOffset();
$emergencyWP->admin_menu();
$emergencyWP->registerCustomePostTypes();
$emergencyWP->addShortcodes();

$cron = new emergencyWPCron();
$schedules = wp_get_schedules();
$messages = new emergencyWPMessages();

?>