<?php

class emergencyWPAdmin
{

    public static $pluginTextdomain = 'emergencywp';
    public static $systemGmtOffset = 0;
    public static $pluginVars;
    public static $blogId = null;
    public static $notices = array('error', 'success', 'hints');
    public static $notice_error = array();
    public static $notice_warning = array();
    public static $notice_update;
    private static $initiated = false;
    private $_classes = array();
    static $emailList = array();
    private static $contactLimit = 3;
    public static $mandatorReactionOptions;
    public static $reminderOptions;

    /**
     * @return int
     */
    public static function getContactLimit()
    {
        $contactLimit = self::$contactLimit;
        $contactLimit = apply_filters('wpEmergency_contacts_limit', $contactLimit);
        return $contactLimit;
    }

    public function __construct()
    {
        $classes = array(
            'cron'
        );
        foreach ($classes as $class) {
            require_once EMERGENCY_WP_PLUGIN_DIR . "lib/class.emergencyWP" . ucwords($class) . ".php";
            $classname = 'emergencywp' . ucwords($class);
            if (class_exists($classname) && $classname != 'emergencyWPAdmin') {
                $this->_classes[$class] = new $classname();
            }
        }

        $notices = get_option('emergencywp_error_notices');
        $short_code = EWP_ShortCodes::JOB_HANDLER;
        if (!$this->ewp_ConfirmationPageWithShortCodeActive($short_code)) {
            if (!is_array($notices)) {
                $notices = array();
            } else if (isset($notices['emergencywp_confirmation_page'])) {
                unset($notices['emergencywp_confirmation_page']);
            }

            $notices['emergencywp_confirmation_page'][] = sprintf(__('EmergencyWP: The required shortcode [%s] was not found on confirmation page. <a href="%s">Go to settings</a>', 'emergencywp_trustees'), $short_code, 'admin.php?page=emergencywp&subpage=settings');
        } else {
            if (isset($notices['emergencywp_confirmation_page'])) {
                unset($notices['emergencywp_confirmation_page']);
            }
        }
        update_option('emergencywp_error_notices', $notices);
        self::$mandatorReactionOptions = array(
            '604800' => __('7 days', 'emergencywp'),
            '0' => __('Pause (not recommended)', 'emergencywp'),
            '3600' => __('1 hour minimum (for testing purposes!)', 'emergencywp'),
            '120' => __('2 minutes minimum (for testing purposes!)', 'emergencywp')
        );

        self::$reminderOptions = array(
            '345600' => __('4 days', 'emergencywp'),
            '3600' => __('1 hour (for testing purposes)', 'emergencywp'),
            '120' => __('2 minutes (for testing purposes)', 'emergencywp')
        );
    }

    public static function init()
    {
        if (!self::$initiated) {
            self::init_hooks();
        }
    }


    public static function getSiteDomainSlug()
    {
        $domain = str_replace('.', '_', get_option('siteurl'));
        $domain = str_replace('http://', '', $domain);
        $domain = str_replace('https://', '', $domain);
        $domain = str_replace('www.', '', $domain);

        return $domain;
    }

    public static function getEmailList()
    {
        if (self::is_wpemergency_trusty_plugin_active()) {
            $emailList = array(
                array("id" => 1, "subject" => "EmergencyWP email", "title" => '01 User Lifecheck', "file" => '01-user-lifecheck', "is_default" => true, "add_on" => "ewp", "aliveInfo" => UserStatus::ALIVE),
                array("id" => 2, "subject" => "EmergencyWP email", "title" => '02 User Lifecheck Reminder', "file" => '02-user-lifecheck_reminder', "is_default" => true, "add_on" => "ewp", "aliveInfo" => UserStatus::HOLD_A),
                array("id" => 3, "subject" => "EmergencyWP email", "title" => '03 Trustee Invitiation', "file" => '03-trustee-invitation', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::VERIFIER_CONFIRM),
                array("id" => 4, "subject" => "EmergencyWP email", "title" => '04 Trustee Invitation Reminder', "file" => '04-trustee-invitation_reminder', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::VERIFIER_REMINDER),
                array("id" => 5, "subject" => "EmergencyWP email", "title" => '05a Trustee Acceptance', "file" => '05a-trustee-acceptance', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::VERIFIER_EMAIL_ACCEPTANCE),
                array("id" => 6, "subject" => "EmergencyWP email", "title" => '05b Trustee Rejection', "file" => '05b-trustee-rejection', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::VERIFIER_EMAIL_REJECTION),
                array("id" => 7, "subject" => "EmergencyWP email", "title" => '06 Trustee Request', "file" => '06-trustee-request', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::FINAL_HOLD_A),
                array("id" => 8, "subject" => "EmergencyWP email", "title" => '07 Trustee Feedback Missing', "file" => '07-trustee-feedback_missing', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::FINAL_HOLD_D),
                array("id" => 9, "subject" => "EmergencyWP email", "title" => '08 Trustee No Reaction', "file" => '08-trustee-no_reaction', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::NO_REACTIONS_A),
                array("id" => 10, "subject" => "EmergencyWP email", "title" => '09 User No Reaction Situation Unclear', "file" => '09-user-no_reaction_situation_unclear', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::HOLD_B),
                array("id" => 11, "subject" => "EmergencyWP email", "title" => '10 Trustee Different Feedback Notice', "file" => '10-trustee-different_feedback_notice', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::FINAL_HOLD_C_TRUSTEES_INFO),
                array("id" => 12, "subject" => "EmergencyWP email", "title" => '11 User Different Trustee Feedback', "file" => '11-user-different_trustee_feedback', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::FINAL_HOLD_C_MANDATOR),
                array("id" => 13, "subject" => "EmergencyWP email", "title" => '12 Trustee Second Request', "file" => '12-trustee-second_request', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::FINAL_HOLD_C_TRUSTEES_CONFIRM),
                array("id" => 14, "subject" => "EmergencyWP email", "title" => '13 Trustee Email Reconfirmation', "file" => '13-trustee-email_reconfirmation', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::TRUSTEES_EMAIL_CONFIRM),
                array("id" => 15, "subject" => "EmergencyWP email", "title" => '20 Trustee Email Update', "file" => '20-trustee-email_update', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::VERIFIER_EMAIL_UPDATE),
                array("id" => 16, "subject" => "EmergencyWP email", "title" => '21 Emergency Trigger Email', "file" => '21-emergency_email', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::EMERGENCY_EMAIL),
                array("id" => 17, "subject" => "EmergencyWP email", "title" => '22 Emergency Verification Email', "file" => '22-emergency_verify_email', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::EMERGENCY_VERIFY_EMAIL),
                array("id" => 18, "subject" => "EmergencyWP email", "title" => '23 Emergency User Email', "file" => '23-emergency_user_email', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::EMERGENCY_USER_EMAIL),
                array("id" => 19, "subject" => "EmergencyWP email", "title" => '24 Trustee Emergency Trigger Email', "file" => '24-trustees_trigger_notification', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::EMERGENCY_TRUSTEE_EMAIL),
                array("id" => 20, "subject" => "EmergencyWP email", "title" => '25 Trustee Email Might Have Changed', "file" => '25-trustees_email_might_have_changed', "is_default" => true, "add_on" => "trustees", "aliveInfo" => UserStatus::TRUSTEE_EMAIL_CHANGED),
            );
            if (self::is_wpemergency_dc_plugin_active()) {
                array_push($emailList,
                    array(
                        "id" => 30,
                        "subject" => "EmergencyWP email",
                        "title" => '30 Message Not Delivered Notification',
                        "file" => '30-message-not-delivered-notification',
                        "is_default" => true,
                        "add_on" => "dc",
                        "aliveInfo" => UserStatus::MESSAGE_NOTIFICATION
                    )
                );
            }
            array_push($emailList,
                array("id" => 99, "subject" => "EmergencyWP email", "title" => '99 Contact Future Mail', "file" => '99-contact-future_mail', "is_default" => true, "add_on" => "ewp", "aliveInfo" => UserStatus::DEAD)
            );

        } else {
            $emailList = array(
                array(
                    "id" => 1,
                    "subject" => "EmergencyWP email",
                    "title" => '01 User Lifecheck',
                    "file" => '01-user-lifecheck',
                    "is_default" => true,
                    "add_on" => "ewp",
                    "aliveInfo" => UserStatus::ALIVE
                ),
                array(
                    "id" => 2,
                    "subject" => "EmergencyWP email",
                    "title" => '02 User Lifecheck Reminder',
                    "file" => '02-user-lifecheck_reminder',
                    "is_default" => true,
                    "add_on" => "ewp",
                    "aliveInfo" => UserStatus::HOLD_A
                )
            );

            if (self::is_wpemergency_dc_plugin_active()) {
                array_push($emailList,
                    array(
                        "id" => 30,
                        "subject" => "EmergencyWP email",
                        "title" => '30 Message Not Delivered Notification',
                        "file" => '30-message-not-delivered-notification',
                        "is_default" => true,
                        "add_on" => "dc",
                        "aliveInfo" => UserStatus::MESSAGE_NOTIFICATION
                    )
                );
            }
            array_push($emailList,
                array(
                    "id" => 99,
                    "subject" => "EmergencyWP email",
                    "title" => '99 Contact Future Mail',
                    "file" => '99-contact-future_mail',
                    "is_default" => true,
                    "add_on" => "ewp",
                    "aliveInfo" => UserStatus::DEAD
                )
            );
        }
        $emailList = apply_filters('emergencyWP_email_list', $emailList);
        usort($emailList, "ewp_cmp_by_email_id");

        self::$emailList = $emailList;
        return $emailList;
    }

    /**
     * @param unknown $class
     * @param unknown $args
     *
     * @return unknown
     * @throws Exception
     */
    public function __call($class, $args)
    {
        if (!isset($this->_classes[$class])) {
            if (WP_DEBUG) {
                throw new Exception("Class $class doesn't exists", 1);
            } else {
                $class = 'empty';
            }
        }

        return $this->_classes[$class];
    }

    public static function init_hooks()
    {
        self::$initiated = true;
        add_action('admin_enqueue_scripts', array('emergencyWPAdmin', 'load_resources'));
        add_filter('send_password_change_email', '__return_false');
        add_action('admin_notices', array('emergencyWPAdmin', 'emergencyWPAdminNotices'));
        add_action('emergencywp_remove_notice_licence', array('emergencyWPAdmin', 'licence_notice_closed'));

        add_action('wp_ajax_save_ewp_dashboard_widgets', array('emergencyWPAdmin', 'save_ewp_dashboard_widgets'));
        add_action('wp_ajax_save_ewp_dashboard_widget_visibility', array('emergencyWPAdmin', 'save_ewp_dashboard_widget_visibility'));
        add_action('wp_ajax_emergencyWP_notice_dismiss', array('emergencyWPAdmin', 'notice_dismiss'));
        add_action('wp_ajax_nopriv_emergencyWP_notice_dismiss', array('emergencyWPAdmin', 'notice_dismiss'));

        add_action('wp_ajax_emergencywp_cron', array('emergencyWPAdmin', 'life_check_cron_job'));

        add_filter('display_post_states', array('emergencyWPAdmin', 'emergencywp_custom_post_states'), 10, 2);
        if (class_exists('EmergencyWPPro')) {
            add_action('wp_dashboard_setup', array('emergencyWPAdmin', 'ewp_dashboard_widgets'));
        }

        add_action('wpEmergency_form_settings_page_re_captcha_ui', array('EwpSettings', 're_captcha_ui'));
        // add CAPTCHA header script to WordPress header

        add_action( "wp_ajax_resetAliveStatus", array('emergencyWPAdmin', "ewp_ajax_resetAliveStatus" ));
        add_action( "wp_ajax_nopriv_resetAliveStatus", array('emergencyWPAdmin', "ewp_ajax_resetAliveStatus" ));

	    add_action('wp_ajax_emergencywp_send_test_email', array('emergencyWPAdmin', 'emergencywp_send_test_email'));
	    //add_action("wp_ajax_my_user_vote", "my_user_vote");
	    //add_action("wp_ajax_nopriv_my_user_vote", "my_must_login");
    }

    static function ewp_dashboard_widgets()
    {
        global $wp_meta_boxes;
        if (current_user_can('publish_emergencywp_messages')) {
            wp_add_dashboard_widget('ewp_last_life_check_widget', __('Last Lifecheck', 'emergencywp'), array('emergencyWPAdmin', 'main_dashboard_last_life_check_widget'));
            wp_add_dashboard_widget('ewp_next_life_check_widget', __('Next Lifecheck', 'emergencywp'), array('emergencyWPAdmin', 'main_dashboard_next_life_check_widget'));
            wp_add_dashboard_widget('ewp_life_check_widget', __('Lifecheck Frequency', 'emergencywp'), array('emergencyWPAdmin', 'main_dashboard_life_check_widget'));
            wp_add_dashboard_widget('ewp_reaction_widget', __('Confirmation Timeframe', 'emergencywp'), array('emergencyWPAdmin', 'main_dashboard_reaction_widget'));
            wp_add_dashboard_widget('ewp_messages_widget', __('Messages', 'emergencywp'), array('emergencyWPAdmin', 'main_dashboard_messages_widget'));
            wp_add_dashboard_widget('ewp_contacts_widget', __('Contacts', 'emergencywp'), array('emergencyWPAdmin', 'main_dashboard_contacts_widget'));
            wp_add_dashboard_widget('ewp_settings_widget', __('EmergencyWP Settings', 'emergencywp'), array('emergencyWPAdmin', 'main_dashboard_settings_widget'));

            if (emergencyWPAdmin::is_wpemergency_trusty_plugin_active()) {
                wp_add_dashboard_widget('ewp_trustees_widget', __('Active Trustees', 'emergencywp'), array('emergencyWPAdmin', 'main_dashboard_trustee_widget'));
            }

            foreach ($wp_meta_boxes['dashboard']['normal']['core'] AS $key => $widget) {
                if ($key == 'ewp_contacts_widget' || $key == 'ewp_messages_widget' || $key == 'ewp_settings_widget') {
                } else if ($key == 'ewp_next_life_check_widget' || $key == 'ewp_last_life_check_widget') {
                    unset($wp_meta_boxes['dashboard']['normal']['core'][$key]);
                    $wp_meta_boxes['dashboard']['side']['core'][$key] = $widget;
                } else if ($key == 'ewp_life_check_widget') {
                    unset($wp_meta_boxes['dashboard']['normal']['core'][$key]);
                    $wp_meta_boxes['dashboard']['column3']['core'][$key] = $widget;
                } else if ($key == 'ewp_reaction_widget' || $key == 'ewp_trustees_widget') {
                    unset($wp_meta_boxes['dashboard']['normal']['core'][$key]);
                    $wp_meta_boxes['dashboard']['column4']['core'][$key] = $widget;
                }
            }
        }
    }

    static function main_dashboard_trustee_widget()
    {
        self::renderDashboardWidget(DashboardWidgets::TRUSTEES, null);
    }

    static function main_dashboard_messages_widget()
    {
        self::renderDashboardWidget(DashboardWidgets::MESSAGES, null);
    }

    static function main_dashboard_contacts_widget()
    {
        self::renderDashboardWidget(DashboardWidgets::CONTACTS, null);
    }

    static function main_dashboard_settings_widget()
    {
        self::renderDashboardWidget(DashboardWidgets::SETTINGS, null);
    }

    static function main_dashboard_last_life_check_widget()
    {
        self::renderDashboardWidget(DashboardWidgets::LAST_LIFE_CHECK, null);
    }

    static function main_dashboard_next_life_check_widget()
    {
        self::renderDashboardWidget(DashboardWidgets::NEXT_LIFE_CHECK, null);
    }

    static function main_dashboard_life_check_widget()
    {
        self::renderDashboardWidget(DashboardWidgets::LIFE_CHECK, null);
    }

    static function main_dashboard_reaction_widget()
    {
        self::renderDashboardWidget(DashboardWidgets::REACTION_TIME_FRAME, null);
    }

    public static function login_lifecheck($user_login, $user)
    {
        $mandator = emergencyWPAdmin::getMandatorData();
        if (class_exists('EmergencyWPPro')) {
            $lifeCheckLoginSetting = ewp_get_option(EWPSettingsData::LIFECHECK_ON_LOGIN, false, true);
            if ($lifeCheckLoginSetting == EWPSettingsData::LIFECHECK_ON_ENABLED && $user->user_email == $mandator['email']) {
                //perform login lifecheck
                $success = __('We are glad to hear that you are still alive. ', 'emergencywp');
                emergencyWPJobController::setAliveStatus(UserStatus::ALIVE, 'login', $success);
            }
        }
    }

    static function emergencywp_add_user_role()
    {
        global $wp_roles;
        if (!isset($wp_roles))
            $wp_roles = new WP_Roles();

        $adm = $wp_roles->get_role('contributor');
        //Adding a 'new_role' with all admin caps
        $wp_roles->remove_role('emergencywp');
        $wp_roles->add_role('emergency_wp', 'EmergencyWP Role', $adm->capabilities);

        $role = 'emergency_wp';
        $wp_roles->add_cap($role, 'edit_pages');
        $wp_roles->add_cap($role, 'edit_published_pages');
        $wp_roles->add_cap($role, 'publish_pages');
        $wp_roles->add_cap($role, 'publish_emergencywp_messages');
        $wp_roles->add_cap($role, 'edit_emergencywp_messages');
        $wp_roles->add_cap($role, 'edit_others_emergencywp_messages');
        $wp_roles->add_cap($role, 'delete_emergencywp_messages');
        $wp_roles->add_cap($role, 'delete_others_emergencywp_messages');
        $wp_roles->add_cap($role, 'edit_emergencywp_message');
        $wp_roles->add_cap($role, 'delete_emergencywp_message');
        $wp_roles->add_cap($role, 'read_emergencywp_message');
        $wp_roles->add_cap($role, 'edit_emergencywp_vaults');
        $wp_roles->add_cap($role, 'edit_emergencywp_vault');
        $wp_roles->add_cap($role, 'edit_others_emergencywp_vaults');
        $wp_roles->add_cap($role, 'delete_emergencywp_vaults');
        $wp_roles->add_cap($role, 'delete_emergencywp_vault');
        $wp_roles->add_cap($role, 'delete_others_emergencywp_vaults');
        $wp_roles->add_cap($role, 'read_emergencywp_vaults');
        $wp_roles->add_cap($role, 'read_private_emergencywp_vaults');
        $wp_roles->add_cap($role, 'publish_emergencywp_vaults');
        $wp_roles->add_cap($role, 'read_emergencywp_vaults');
        $wp_roles->add_cap($role, 'delete_emergencywp_vault');
    }

    static function emergency_wp_role_remove_menus()
    {
        $current_user = wp_get_current_user();
        if (isset($current_user->roles[1])) {
            $user_role = $current_user->roles[1];
        } else if (isset($current_user->roles[0])) {
            $user_role = $current_user->roles[0];
        } else {
            $user_role = $current_user->roles;
        }

        if ($user_role == 'emergency_wp') {
            remove_menu_page('edit.php');
            remove_menu_page('edit-comments.php');
            remove_menu_page('tools.php');
        }
    }

    static function emergencywp_custom_post_states($states, $post)
    {

        $eWPJobConfirmationPage = get_option(EWP_initPluginVars::$pluginPages['job_response_options']['pageId']);
        if ('page' == get_post_type($post->ID) && $post->ID == $eWPJobConfirmationPage) {
            $states[] = __('EmergencyWP life check page', 'emergencywp');
        }

        return $states;
    }

    public static function save_ewp_dashboard_widgets()
    {
        if (isset($_POST['column-1'])) {
            update_option('emergencyWP_dashboard_widgets_column_1', sanitize_text_field($_POST['column-1']));
        } else {
            update_option('emergencyWP_dashboard_widgets_column_1', array());
        }
        if (isset($_POST['column-2'])) {
            update_option('emergencyWP_dashboard_widgets_column_2', sanitize_text_field($_POST['column-2']));
        } else {
            update_option('emergencyWP_dashboard_widgets_column_2', array());
        }
        if (isset($_POST['column-3'])) {
            update_option('emergencyWP_dashboard_widgets_column_3', sanitize_text_field($_POST['column-3']));
        } else {
            update_option('emergencyWP_dashboard_widgets_column_3', array());
        }
        wp_die();
    }

    public static function save_ewp_dashboard_widget_visibility()
    {
        if (isset($_POST['column']) && isset($_POST['state'])) {
            $dashboardColumnsVisibility = get_option('emergencyWP_dashboard_widgets_visibility');
            $dashboardColumnsVisibility[sanitize_text_field($_POST['column'])] = sanitize_text_field($_POST['state']);
            update_option('emergencyWP_dashboard_widgets_visibility', $dashboardColumnsVisibility);
        }
        wp_die();
    }

    public function admin_menu()
    {
        add_action('admin_menu', array('emergencyWPAdmin', 'add_admin_menu'), 10);
        add_action('admin_menu', array('emergencyWPAdmin', 'my_remove_meta_boxes'));
        add_action('do_meta_boxes', array('emergencyWPAdmin', 'remove_plugin_metaboxes'));

    }

    public static function is_wpemergency_trusty_plugin_active()
    {
        if (defined('EMERGENCY_WP_TRUSTY_PLUGIN_PATH')) {
            return in_array(EMERGENCY_WP_TRUSTY_PLUGIN_PATH,
                    (array)get_option('active_plugins', array()))
                || (is_multisite() && is_plugin_active_for_network(EMERGENCY_WP_TRUSTY_PLUGIN_PATH)
                );
        } else {
            return false;
        }
    }

    public static function is_wpemergency_vault_plugin_active()
    {
        if (defined('EMERGENCY_WP_VAULT_PLUGIN_PATH')) {
            return in_array(EMERGENCY_WP_VAULT_PLUGIN_PATH,
                    (array)get_option('active_plugins', array()))
                || (is_multisite() && is_plugin_active_for_network(EMERGENCY_WP_VAULT_PLUGIN_PATH)
                );
        } else {
            return false;
        }
    }
    public static function is_wpemergency_dc_plugin_active()
    {
        if (defined('EMERGENCY_WP_DELIVERY_CONDITIONS_PLUGIN_PATH')) {
            return in_array(EMERGENCY_WP_DELIVERY_CONDITIONS_PLUGIN_PATH,
                    (array)get_option('active_plugins', array()))
                || (is_multisite() && is_plugin_active_for_network(EMERGENCY_WP_TRUSTY_PLUGIN_PATH)
                );
        } else {
            return false;
        }
    }

    public static function getMandatorData($blogId = null)
    {
        if (is_multisite()) {
            if ($blogId === null) {
                $blogId = self::$blogId;
            }
            switch_to_blog($blogId);
        }

        $mandator = get_option('emergencywp_mandator');
        if (!$mandator) {
            $args = [
                'orderby' => 'ID',
                'order' => 'ASC',
                'role' => 'administrator'
            ];
            // get user data of first WP user - sort by ID DESC (to get the last registered admin user - role: 'administrator')
            $users = get_users($args);
            $user_email = $users[0]->data->user_email;

            $user_first_name = '';
            $user_meta_first_name = get_user_meta($users[0]->ID, 'first_name');
            if (is_array($user_meta_first_name)) {
                $user_first_name = $user_meta_first_name[0];
            }

            $user_last_name = '';
            $user_meta_last_name = get_user_meta($users[0]->ID, 'last_name');
            if (is_array($user_meta_last_name)) {
                $user_last_name = $user_meta_last_name[0];
            }

            // set Mandator default data
            $mandator = self::setDefaultMandatorRawData();
            $mandator['id'] = $users[0]->ID;
            $mandator['email'] = $user_email;
            $mandator['firstName'] = $user_first_name;
            $mandator['lastName'] = $user_last_name;

            self::setMandatorData($mandator, $blogId);
        }

        if (is_multisite()) {
            restore_current_blog();
        }

        return $mandator;
    }

    public static function setMandatorData($mandator = false, $blogId = null)
    {
        if (!$mandator) {
            return [
                'status' => 'error',
                'errors' => [__('Missing mandator data on mandator data update', 'emergencywp')]
            ];
        }

        // make some data checks
        if (!filter_var($mandator['email'], FILTER_VALIDATE_EMAIL)) {
            return [
                'status' => 'error',
                'errors' => [__('Mandator email is not a valid email address', 'emergencywp')]
            ];
        }
        if (strlen($mandator['firstName']) < 2) {
            return [
                'status' => 'error',
                'errors' => [__('The first name should consist of at least two letters', 'emergencywp')]
            ];
        }
        if (strlen($mandator['lastName']) < 2) {
            return [
                'status' => 'error',
                'errors' => [__('The last name should consist of at least two letters', 'emergencywp')]
            ];
        }

        if (is_multisite()) {
            if ($blogId === null) {
                $blogId = self::$blogId;
            }
            switch_to_blog(self::$blogId);
        }

        $res = update_option('emergencywp_mandator', $mandator);

        if (is_multisite()) {
            restore_current_blog();
        }

        if ($res) {
            return [
                'status' => 'successful',
                'mandatorData' => $mandator,
                'errors' => []
            ];
        } else {
            return [
                'status' => 'error',
                'mandator' => null,
                'errors' => [__('Something went wrong on updated mandator email address', 'emergencywp')]
            ];
        }
    }

    public static function setDefaultMandatorRawData()
    {
        return [
            'firstName' => '',
            'lastName' => '',
            'email' => ''
        ];
    }

    public static function getSystemGmtOffset()
    {
        //TODO Do we need this?
        //date_default_timezone_set('UTC');
        self::$systemGmtOffset = get_option('gmt_offset');
    }

    public static function remove_plugin_metaboxes()
    {
        remove_meta_box('ef_editorial_meta', 'emergencywp_messages', 'side'); // Remove Edit Flow Editorial Metadata
    }

    public static function my_remove_meta_boxes()
    {
        remove_meta_box('submitdiv', 'emergencywp_messages', 'normal');
        remove_meta_box('submitdiv', 'emergencywp_contacts', 'normal');
        remove_meta_box('submitdiv', 'emergencywp_trustees', 'normal');
    }

    public static function add_admin_menu()
    {
        load_plugin_textdomain('emergencywp', false, dirname(plugin_basename(__FILE__)));

        $minCapability = emergencyWPAdmin::getMinCapability();
        add_menu_page(__('EmergencyWP', 'emergencywp'), __('EmergencyWP', 'emergencywp'), $minCapability, 'emergencywp', array('emergencyWPAdmin', 'load_page'), EMERGENCY_WP_PLUGIN_URL . 'assets/images/hearth_icon.svg', 2);

        add_submenu_page('emergencywp',
            __('Dashboard', 'emergencywp'),
            __('Dashboard', 'emergencywp'),
            $minCapability,
            'emergencywp',
            array('emergencyWPAdmin', 'load_page')
        );

        add_submenu_page('emergencywp',
            __('Settings', 'emergencywp'),
            __('Settings', 'emergencywp'),
            $minCapability,
            'emergencywp&subpage=settings',
            array('emergencyWPAdmin', 'load_page')
        );

        do_action('emergencywp_additional_menus');

	    if (!is_multisite()) {
		    if (defined('EWP_TRUSTEES_SL_ITEM_ID') ||
			    defined('EWP_SL_DC_ITEM_ID') ||
			    defined('EWP_VAULT_SL_ITEM_ID') ||
			    (defined('EWP_MULTI_SITE_SL_ITEM_ID') && is_multisite()) ||
			    defined('EWP_PRO_SL_ITEM_ID')) {
			    add_submenu_page('emergencywp',
				    __('Licenses', 'emergencywp'),
				    __('Licenses', 'emergencywp'),
				    $minCapability,
				    'emergencywp-licences',
				    array('emergencyWPLicences', 'view_licences'));
		    }
	    }
    }

    public static function registerPostStatus()
    {
        if (isset(EWP_initPluginVars::$pluginCustomPostTypes)) {
            if (count(EWP_initPluginVars::$pluginCustomPostTypes)) {
                foreach (EWP_initPluginVars::$pluginCustomPostTypes as $key => $pluginCustomePostType) {
                    register_post_status($key, array(
                        'label' => __($pluginCustomePostType['label'] . ' EmergencyWP Custom Post Type', 'emergencywp'),
                        'public' => true,
                        'exclude_from_search' => false,
                        'show_in_admin_all_list' => false,
                        'show_in_admin_status_list' => false
                    ));
                }
            }
        }
    }

    public static function load_resources()
    {
        /**
         * Enqueue scripts and styles for editing pages of 'emergencywp' post type only
         *
         * @return void
         */

        $screen = get_current_screen();
        $screenBase = strtolower($screen->base);
        $screenPostType = strtolower($screen->post_type);
        $screenId = strtolower($screen->id);

        // Check screen base and current post type
        if (strpos($screenBase, 'emergencywp') >= 0
            || strpos($screenPostType, 'emergencywp') >= 0
            || strpos($screenId, 'emergencywp') >= 0
        ) {
            wp_register_style('emergency_wp_admin_css', EMERGENCY_WP_PLUGIN_URL . 'assets/css/admin-style.css', false, '1.0.1');
            wp_enqueue_style('emergency_wp_admin_css');
            // Enqueue other scripts and styles
        }

        // todo: check this following if queries again ... not sure if this works already!!!
        $emergencyWPCustomeCss = false;
        $screenBaseCssFile = $screenIdCssFile = $screenPostTypeCssFile = '';

        if (strpos($screenBase, 'emergencywp') !== false) {
            $screenBaseCssFile = substr($screenBase, strrpos($screenBase, 'emergencywp'));
            if (file_exists(EMERGENCY_WP_PLUGIN_DIR . "assets/css/" . $screenBaseCssFile . ".css")) {
                // load emergencyWP post type stylesehht, if it exists
                wp_register_style($screenBaseCssFile, EMERGENCY_WP_PLUGIN_URL . 'assets/css/' . $screenBaseCssFile . '.css', false, '1.0.0');
                wp_enqueue_style($screenBaseCssFile);
                $emergencyWPCustomeCss = true;
            }
        }

        if (strpos($screenId, 'emergencywp') !== false
            && !$emergencyWPCustomeCss
        ) {
            $screenIdCssFile = substr($screenId, strrpos($screenId, 'emergencywp'));
            if (file_exists(EMERGENCY_WP_PLUGIN_DIR . "assets/css/" . $screenIdCssFile . ".css")) {
                // load emergencyWP post type stylesehht, if it exists
                wp_register_style($screenIdCssFile, EMERGENCY_WP_PLUGIN_URL . 'assets/css/' . $screenIdCssFile . '.css', false, '1.0.0');
                wp_enqueue_style($screenIdCssFile);
                $emergencyWPCustomeCss = true;
            }
        }

        if (strpos($screenPostType, 'emergencywp') !== false
            && !$emergencyWPCustomeCss
        ) {
            $screenPostTypeCssFile = substr($screenId, strrpos($screenPostType, 'emergencywp'));
            if (file_exists(EMERGENCY_WP_PLUGIN_DIR . "assets/css/" . $screenPostTypeCssFile . ".css")) {
                // load emergencyWP post type stylesehht, if it exists
                wp_register_style($screenPostTypeCssFile, EMERGENCY_WP_PLUGIN_URL . 'assets/css/' . $screenPostTypeCssFile . '.css', false, '1.0.0');
                wp_enqueue_style($screenPostTypeCssFile);
                $emergencyWPCustomeCss = true;
            }
        }

        wp_localize_script('clipboard', 'emergencywpClipboardValue', array(
            'copied' => __('Copied!', 'emergencywp'),
        ));
        wp_enqueue_script('clipboard');

        wp_register_script('jquery-modal.js', EMERGENCY_WP_PLUGIN_URL . 'assets/js/jquery.modal.min.js', array('jquery'), EMERGENCY_WP_VERSION, true);
        wp_register_style('jquery-modal.css', EMERGENCY_WP_PLUGIN_URL . 'assets/css/jquery.modal.min.css', false, '0.9.1');
        wp_enqueue_style('jquery-modal.css');
        wp_register_script('emergencyWP.js', EMERGENCY_WP_PLUGIN_URL . 'assets/js/emergencyWP.js', array('jquery'), EMERGENCY_WP_VERSION, true);

        // Now we can localize the script with our data.
        $translation_array = array(
            'EMERGENCY_WP_PLUGIN_URL' => EMERGENCY_WP_PLUGIN_URL,
            'ajaxurl' => admin_url( 'admin-ajax.php' )
        );
        wp_localize_script('emergencyWP.js', 'emergencywp', $translation_array);




        // The script can be enqueued now or later.
        wp_enqueue_script('emergencyWP.js');
        wp_enqueue_script('emergencyWP-notice', EMERGENCY_WP_PLUGIN_URL . 'assets/js/notice-script.js', array('jquery'), EMERGENCY_WP_VERSION, true);
        wp_enqueue_script('jquery-modal.js');

        wp_enqueue_script('jquery-ui-sortable');
        wp_enqueue_script('activate_sortable', EMERGENCY_WP_PLUGIN_URL . '/assets/js/activate_sortable.js', array('jquery-ui-sortable'), null, true);

        self::ewp_add_deactivation_popup();
    }

    public static function registerCustomePostTypes()
    {
        add_action('init', array('emergencyWPAdmin', 'registerPostStatus'));
        add_action('init', array('emergencyWPSystemEmails', 'initPostType'));
        add_action('init', array('emergencyWPMessages', 'initPostType'));
        add_action('init', array('emergencyWPContacts', 'initPostType'));
    }

    public static function load_page()
    {

        $parts = explode('-', sanitize_text_field($_GET['page']));
        if (!isset($parts[1])) {
            $parts[1] = 'settings';
        }
        self::includeMenuPage($parts);
    }

    public static function is_edit_page($new_edit = null)
    {
        global $pagenow;
        //make sure we are on the backend
        if (!is_admin()) {
            return false;
        }


        if ($new_edit == "edit") {
            return in_array($pagenow, array('post.php',));
        } elseif ($new_edit == "new") //check for new post page
        {
            return in_array($pagenow, array('post-new.php'));
        } else //check for either new or edit
        {
            return in_array($pagenow, array('post.php', 'post-new.php'));
        }
    }

    public function addShortcodes()
    {
        add_shortcode(EWP_ShortCodes::JOB_HANDLER, array('emergencyWPShortcodes', 'job_handling_shortcode'));
    }

    public static function setAdminNotice($type = null, $post_type = null, $hint = null)
    {
        if (is_null($type) || is_null($post_type) || is_null($hint)) {
            return;
        }

        $notices = get_option('emergencywp_' . $type . '_notices');
        $notices['emergencywp_' . $post_type][] = $hint;
        update_option('emergencywp_' . $type . '_notices', $notices);
    }

    public static function emergencyWPAdminNotices()
    {
        self::showAdminNotices('updated');
        self::showAdminNotices('update-nag');
        self::showAdminNotices('error');
    }


    public static function loadTranslationWording($type = null, $mainKey = null, $keyName = null)
    {
        global $wpdb;

        return '';
    }

    public static function showAdminNotices($type)
    {
        $notices = get_option('emergencywp_' . $type . '_notices');
        $notices = apply_filters('emergencywp_admin_notices', $type);

        if (!empty($notices)) {
            $screen = get_current_screen();
            $wpNoticeClassName = 'notice-';
            switch ($type) {
                case 'update':
                    $wpNoticeClassName .= 'success';
                    break;
                case 'update-nag':
                    $wpNoticeClassName .= 'warning';
                    break;
                case 'error':
                    $wpNoticeClassName .= 'error';
                    break;
                default:
                    $wpNoticeClassName = '';
            }
            if (!empty($notices[$screen->post_type])) {
                echo '<div class="notice ' . esc_html($wpNoticeClassName) . ' ' . esc_html($type) . '  is-dismissible">';
                foreach ($notices[$screen->post_type] as $v) {
                    echo '<p><strong>' . esc_html($v) . '</strong></p>';
                }
                echo '</div>';
                unset($notices[$screen->post_type]);
                update_option('emergencywp_' . $type . '_notices', $notices);
            } else if (!empty($notices['emergencywp_settings'])) {
                echo '<div class="notice ' . esc_html($wpNoticeClassName) . ' ' . esc_html($type) . '  is-dismissible">';
                foreach ($notices['emergencywp_settings'] as $v) {
                    echo '<p><strong>' . esc_html($v) . '</strong></p>';
                }
                echo '</div>';
                unset($notices['emergencywp_settings']);
                update_option('emergencywp_' . $type . '_notices', $notices);
            } else if (!empty($notices['emergencywp_confirmation_page'])) {
                echo '<div class="notice ' . esc_html($wpNoticeClassName) . ' ' . esc_html($type) . '  is-dismissible">';
                foreach ($notices['emergencywp_confirmation_page'] as $v) {
                    echo '<p><strong>' . esc_html($v) . '</strong></p>';
                }
                echo '</div>';
                unset($notices['emergencywp_confirmation_page']);
                update_option('emergencywp_' . $type . '_notices', $notices);
            } else if (!empty($notices['emergencywp_contact_limit_exceeded'])) {
                echo '<div class="notice ' . esc_html($wpNoticeClassName) . ' ' . esc_html($type) . '  is-dismissible">';
                foreach ($notices['emergencywp_contact_limit_exceeded'] as $v) {
                    echo '<p><strong>' . esc_html($v) . '</strong></p>';
                }
                echo '</div>';
                unset($notices['emergencywp_contact_limit_exceeded']);
                update_option('emergencywp_' . $type . '_notices', $notices);
            } else if (class_exists('EmergencyWPZapierTriggers') && !empty($notices['emergencywp_' . EmergencyWPZapierTriggers::$postTypeSlug])) {
                echo '<div class="notice ' . esc_html($wpNoticeClassName) . ' ' . esc_html($type) . '  is-dismissible">';
                foreach ($notices['emergencywp_' . EmergencyWPZapierTriggers::$postTypeSlug] as $v) {
                    echo '<p><strong>' . esc_html($v) . '</strong></p>';
                }
                echo '</div>';
                unset($notices['emergencywp_' . EmergencyWPZapierTriggers::$postTypeSlug]);
                update_option('emergencywp_' . $type . '_notices', $notices);
            } else if (class_exists('emergencyWPContacts') && !empty($notices['emergencywp_' . emergencyWPContacts::$postTypeSlug])) {
                echo '<div class="notice ' . esc_html($wpNoticeClassName) . ' ' . esc_html($type) . '  is-dismissible">';
                foreach ($notices['emergencywp_' . emergencyWPContacts::$postTypeSlug] as $v) {
                    echo '<p><strong>' . esc_html($v) . '</strong></p>';
                }
                echo '</div>';
                unset($notices['emergencywp_' . emergencyWPContacts::$postTypeSlug]);
                update_option('emergencywp_' . $type . '_notices', $notices);
            }
        }
    }

    public static function getPostMetaValuesOfKey($key = '')
    {
        global $wpdb;

        if (empty($key)) {
            return;
        }
	    return $wpdb->get_col($wpdb->prepare("
			SELECT DISTINCT pm.meta_value FROM {$wpdb->postmeta} pm
			WHERE pm.meta_key = '%s'
			", $key)
        );
    }

    private static function includeMenuPage($dir = null)
    {
        if ($dir[1] == 'main') {
            wp_register_script('emergencyWP_wp_admin', EMERGENCY_WP_PLUGIN_URL . 'assets/js/emergencyWP_settings-scripts.css', false, '1.0.0');
            wp_enqueue_script('emergencyWP_wp_admin');
        }
        if (file_exists(EMERGENCY_WP_PLUGIN_DIR . "pages/" . @$dir[0] . "/" . @$dir[1] . ".php")) {
            include(EMERGENCY_WP_PLUGIN_DIR . "pages/" . $dir[0] . "/" . $dir[1] . ".php");
        } else if (file_exists(EMERGENCY_WP_PLUGIN_DIR . "pages/" . @$dir[0] . "/" . @$dir[1] . "/" . @$dir[2] . ".php")) {
            include(EMERGENCY_WP_PLUGIN_DIR . "pages/" . $dir[0] . "/" . $dir[1] . "/" . $dir[1] . ".php");
        } else {
            return;
        }
    }

    public static function setBlogId($blogId)
    {

        if (!isset($blogId) || !is_numeric($blogId)) {
            return false;
        }
        self::$blogId = $blogId;

        return true;
    }

    public static function getWpPost($args)
    {

        if (!isset($args)) {
            echo "EmergencyWP ERROR [FC: 9999] | class: emergencyWPAdmin<br />";

            return false;
        }

        $emergencyWPWpPost = false;
        if (is_multisite()) {
            if (self::checkBlogId()) {
                if (is_multisite()) {
                    switch_to_blog(self::$blogId);
                }
                $emergencyWPWpPost = get_posts($args);
                if (is_multisite()) {
                    restore_current_blog();
                }
            }
        } else {
            $emergencyWPWpPost = get_posts($args);
        }

        return $emergencyWPWpPost;
    }

    public static function getWpPostMeta($postId, $key = '', $single = false)
    {
        if (!isset($postId)) {
            echo "EmergencyWP ERROR [FC: 9998] | class: emergencyWPAdmin<br />";

            return false;
        }

        $emergencyWPPostMeta = false;
        if (is_multisite()) {
            switch_to_blog(self::$blogId);
            $emergencyWPPostMeta = get_post_meta($postId, $key, $single);
            restore_current_blog();
        } else {
            $emergencyWPPostMeta = get_post_meta($postId, $key, $single);
        }

        return $emergencyWPPostMeta;
    }

    public static function insertWpPost($args = null, $wpError = false)
    {
        $emergencyWPWpPost = false;

        if (is_null($args)) {
            return $emergencyWPWpPost;
        }

        if (is_multisite()) {
            switch_to_blog(self::$blogId);
            $emergencyWPWpPost = wp_insert_post($args, $wpError);
            restore_current_blog();
        } else {
            $emergencyWPWpPost = wp_insert_post($args, $wpError);
        }

        return $emergencyWPWpPost;
    }

    public static function checkBlogId()
    {
        if (is_null(self::$blogId)) {
            $blogId = get_current_blog_id();
            if (is_null($blogId)) {
                echo "EmergencyWP ERROR [FC: 9990] | class: emergencyWPAdmin<br />";

                return false;
            } else {
                self::setBlogId($blogId);
            }
        }

        return true;
    }

    public static function getPermalink($plugIn)
    {
        if (is_multisite()) {
            if (self::checkBlogId()) {
                if (is_multisite()) {
                    switch_to_blog(self::$blogId);
                }
                $responseUrl = get_permalink(get_option(EWP_initPluginVars::$pluginPages[$plugIn]['pageId']));
                if (is_multisite()) {
                    restore_current_blog();
                }

                return $responseUrl;
            }
        } else {
            return get_permalink(get_option(EWP_initPluginVars::$pluginPages[$plugIn]['pageId']));
        }
    }

    public static function getPostMeta($postId, $metaKey = '', $single = true)
    {
        if (is_multisite()) {
            if (self::checkBlogId()) {
                if (is_multisite()) {
                    switch_to_blog(self::$blogId);
                }
                $postMeta = get_post_meta($postId, $metaKey, $single);
                if (is_multisite()) {
                    restore_current_blog();
                }

                return $postMeta;
            }
        } else {
            return get_post_meta($postId, $metaKey, $single);
        }
    }


    public static function updatePostMeta($postId, $metaKey, $newValue = '')
    {
        if (is_multisite()) {
            if (self::checkBlogId()) {
                switch_to_blog(self::$blogId);
                $postMeta = update_post_meta($postId, $metaKey, $newValue);
                restore_current_blog();

                return $postMeta;
            }
        } else {
            return update_post_meta($postId, $metaKey, $newValue);
        }
    }

    public static function deletePostMeta($postId, $metaKey, $deleteValue = '')
    {
        if (is_multisite()) {
            if (self::checkBlogId()) {
                if (is_multisite()) {
                    switch_to_blog(self::$blogId);
                }
                $postMeta = delete_post_meta($postId, $metaKey, $deleteValue);
                if (is_multisite()) {
                    restore_current_blog();
                }

                return $postMeta;
            }
        } else {
            return delete_post_meta($postId, $metaKey, $deleteValue);
        }
    }

    public static function addLicenceNotice()
    {
        if (get_transient('emergencywp_skip_licence_notices')) {
            return;
        }

        $ewpNotices = get_option('emergencyWP_notices');
        if (!is_array($ewpNotices)) {
            $ewpNotices = array();
        }
        if (!isset($ewpNotices['licence'])) {
            $ewpNotices['licence'] = true;
        }

        update_option('emergencyWP_notices', $ewpNotices);
    }


    public static function notice_dismiss()
    {
        $return['success'] = true;

        if (isset($_POST['id'])) {
            ewp_remove_notice(sanitize_key($_POST['id']));
        }
        echo json_encode($return);
        exit;
    }

    public static function licence_notice_closed()
    {
        set_transient('emergencywp_skip_licence_notices', true, WEEK_IN_SECONDS);
    }

    public static function life_check_cron_job()
    {
        include(EMERGENCY_WP_PLUGIN_DIR . 'cron/jobController.php');
    }

    // check the current post for the existence of a short code
    function ewp_ConfirmationPageWithShortCodeActive($shortcode = EWP_ShortCodes::JOB_HANDLER)
    {

        $post_to_check = get_post(get_option(EWP_initPluginVars::$pluginPages['job_response_options']['pageId']));

        // false because we have to search through the post content first
        $found = false;

        // if no short code was provided, return false
        if (!$shortcode) {
            return $found;
        }

        // check the post content for the short code
        if (stripos($post_to_check->post_content, '[' . $shortcode) !== false) {
            // we have found the short code
            $found = true;
        }

        // return our final results
        return $found;
    }

    public static function getMinCapability()
    {
        global $wp_roles;

        $accessUserMinimumRole = emergencywp_option(EWPSettingsData::ACCESS_USER_MINIMUM_ROLE);
        $minCapability = 'manage_options';

        if (is_object($wp_roles)) {
            $roles = $wp_roles->roles;
            if (is_array($roles)) {
                foreach ($roles as $role => $roleInfo) {
                    if ($role == $accessUserMinimumRole) {
                        $capabilities = $roleInfo['capabilities'];
                        foreach ($capabilities AS $capabilityKey => $capabilityEnabled) {
                            if ($capabilityEnabled) {
                                $minCapability = $capabilityKey;
                                break;
                            }
                        }
                    }
                }
            }
        }
        return $minCapability;
    }

    public static function getMinCapabilityKey()
    {
        global $wp_roles;

        $accessUserMinimumRole = emergencywp_option(EWPSettingsData::ACCESS_USER_MINIMUM_ROLE);
        $minCapability = 'manage_options';

        $roles = $wp_roles->roles;
        foreach ($roles as $role => $roleInfo) {
            if ($role == $accessUserMinimumRole) {
                $capabilities = $roleInfo['capabilities'];
                foreach ($capabilities AS $capabilityKey => $capabilityEnabled) {
                    if ($capabilityEnabled) {
                        $minCapability = $capabilityKey;
                        break;
                    }
                }
            }
        }
        return $minCapability;
    }

    public static function getFullDateFormat()
    {
        $dateFormat = emergencywp_option(EWPSettingsData::DATE_FORMAT, "d.m.Y");
        $timeFormat = emergencywp_option(EWPSettingsData::TIME_FORMAT, "H:i");
        return $dateFormat . ' ' . $timeFormat;
    }

    public static function getDateFormat()
    {
	    return emergencywp_option(EWPSettingsData::DATE_FORMAT, "d.m.Y");
    }

    public static function getTimeFormat()
    {
	    return emergencywp_option(EWPSettingsData::TIME_FORMAT, "H:i");
    }

    public static function deleteCustomPosts($postType)
    {
        $allPosts = get_posts(array('post_type' => $postType, 'numberposts' => -1));
        foreach ($allPosts as $deletingPost) {
            wp_delete_post($deletingPost->ID, true);
        }
    }

    public static function deleteCustomPostsWithCustomQuery($postType)
    {
        global $wpdb;
        $result = $wpdb->query(
            $wpdb->prepare("
            DELETE posts,pt,pm
            FROM {$wpdb->prefix}posts posts
            LEFT JOIN {$wpdb->prefix}term_relationships pt ON pt.object_id = posts.ID
            LEFT JOIN {$wpdb->prefix}postmeta pm ON pm.post_id = posts.ID
            WHERE posts.post_type = %s
            ",
                $postType
            )
        );
    }

    public static function deleteEmergencyWPOptionsCustomQuery()
    {
        global $wpdb;
        $result = $wpdb->query(
            $wpdb->prepare("
            DELETE options
            FROM {$wpdb->prefix}options options
            WHERE options.option_name LIKE '%s'
            ",
                '%emergencyWP%'
            )
        );
    }

    public static function ewp_add_deactivation_popup()
    {
        ?>
        <div id="emergancyWP-feedback-content" style="display: none; padding: 16px 16px 0px 16px;">
            <div class="modal-dialog">
                <div class="modal-content ewp-modal-content">
                    <div class="modal-header">
                        <button type="button" class="close" data-dismiss="modal"><span
                                    aria-hidden="true">&times;</span><span class="sr-only">Close</span></button>
                        <h4 class="modal-title"
                            id="myModalLabel"><?php echo @__('EmergencyWP Feedback', 'emergencywp'); ?></h4>
                    </div>
                    <div class="modal-body">
                        <p style="margin-top:-5px"><?php echo esc_attr(__('Were you expecting something else or did it fail to work for you?', 'emergancyWP')); ?></p>
                        <form id="form_deactivation_popup_emergencywp">
                            <?php wp_nonce_field(); ?>
                            <ul id="emergancyWP-deactivate-reasons">
                                <li class="emergancyWP-reason emergancyWP-custom-input">
                                    <label>
                                        <span><input value="1" type="radio" name="ewp_reason"></span>
                                        <span><?php echo esc_attr(__('It\'s a temporary deactivation. I\'m just debugging an issue.', 'emergancyWP')); ?></span>
                                    </label>
                                </li>
                                <li class="emergancyWP-reason emergancyWP-custom-input">
                                    <label>
                                        <span><input value="2" type="radio" name="ewp_reason"/></span>
                                        <span><?php echo esc_attr(__('It didn\'t work as expected.', 'emergancyWP')); ?></span>
                                    </label>
                                </li>
                                <li class="emergancyWP-reason emergancyWP-custom-input">
                                    <label>
                                        <span><input value="3" type="radio" name="ewp_reason"/></span>
                                        <span><?php echo esc_attr(__('I found another software.', 'emergancyWP')); ?></span>
                                    </label>
                                </li>
                                <li class="emergancyWP-reason emergancyWP-custom-input emergancyWP-support">
                                    <label>
                                        <span><input value="4" type="radio" name="ewp_reason"
                                                     id="emergencyWP-expectation-form"/></span>
                                        <span><?php echo esc_attr(__('I didn\'t use it as expected (please describe below).', 'emergancyWP')); ?></span>
                                    </label>
                                </li>
                                <li class="emergancyWP-reason emergancyWP-support">
                                    <label>
                                        <span><input value="5" type="radio" name="ewp_reason"
                                                     checked id="emergencyWP-ticket-form"/></span>
                                        <span><?php echo esc_attr(__('Submit a ticket', 'emergancyWP')); ?></span>
                                    </label>
                                    <div class="emergancyWP-submit-feedback" style="padding: 10px 10px 0px 10px;">
                                        <div class="ewp-feedback-form ewp-flex">
                                            <div class="ewp-grow-1 ewp-first-field ewp-full-width-field">
                                                <strong><?php echo esc_attr(__('Name', 'emergancyWP')); ?> : </strong>
                                                <div class="form-group">
                                                    <input type="text" class="form-control"
                                                           name="ewp_your_name"
                                                           id="ewp_your_name" value="">
                                                </div>
                                            </div>
                                            <div class="ewp-grow-1 ewp-full-width-field">
                                                <strong><?php echo esc_attr(__('Email', 'emergancyWP')); ?> : </strong>
                                                <div class="form-group">
                                                    <input type="email" class="form-control"
                                                           id="ewp_email_address"
                                                           name="ewp_email_address"/>
                                                </div>
                                            </div>
                                        </div>
                                        <strong><?php echo esc_attr(__('Feedback', 'emergancyWP')); ?> : </strong>
                                        <div class="form-group">
                                            <textarea class="form-control" style="width: 100%;"
                                                      name="ewp_textarea_feedback" id="ewp_textarea_feedback"
                                                      rows="2"></textarea>
                                        </div>
                                    </div>
                                </li>
                            </ul>
                        </form>
                    </div>
                    <?php
                    if(!isset($blogID)) {
                        $blogID = 0;
                    }
                    ?>
                    <div class="modal-footer">
                        <a class="button left-button" href="#close-modal"
                           rel="modal:close"><?php echo @__('Abort ', 'emergencywp'); ?>
                        </a>
                        <button type="button" class="button button-primary right-button"
                                id="deactivation-feedback-submit" data-blog-id="<?php echo esc_attr($blogID); ?>">
                            <img src="<?php echo EMERGENCY_WP_PLUGIN_URL . '/assets/images/hearth_icon.gif'; ?>" width="16px"
                                 class="ajax-loading">
                            <?php echo __('Submit', 'emergencywp'); ?>
                        </button>
                        <button type="button" class="button button-secondary right-button"
                                id="deactivation-feedback-skip" data-blog-id="<?php echo esc_attr($blogID); ?>">
                            <?php echo __('Skip', 'emergencywp'); ?>
                        </button>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }

    public static function trimYearFromDateFormat($dateFormat)
    {
        $dateNoYearFormat = $dateFormat;
        $dateNoYearFormat = str_replace('y', '', $dateNoYearFormat);
        $dateNoYearFormat = str_replace('Y', '', $dateNoYearFormat);

        $dateNoYearFormat = rtrim($dateNoYearFormat);
        $dateNoYearFormat = ltrim($dateNoYearFormat);
        $dateNoYearFormat = rtrim($dateNoYearFormat, '.');
        $dateNoYearFormat = ltrim($dateNoYearFormat, '.');
        $dateNoYearFormat = rtrim($dateNoYearFormat, ',');
        $dateNoYearFormat = ltrim($dateNoYearFormat, ',');
        $dateNoYearFormat = rtrim($dateNoYearFormat, '-');
        $dateNoYearFormat = ltrim($dateNoYearFormat, '-');
        $dateNoYearFormat = rtrim($dateNoYearFormat, '/');
        $dateNoYearFormat = ltrim($dateNoYearFormat, '/');

        return $dateNoYearFormat;
    }

    public static function renderDashboardWidget($widgetName, $widgetsVisibility)
    {
        $debug = false;
        $settingsHaveBeenUpdated = false;
        $aliveInfo = get_option('emergencyWP_alive_status');
        $UTC = new DateTimeZone("UTC");
        $lastLifeCheck = date_create_from_format('Y-m-d H:i:s', $aliveInfo['lastFeedback'], $UTC);

        $jobSettings = get_option('emergencyWP_job_settings');
        if (@$_POST['settings-dashboard-save'] == 'save') {
            $mandator_reaction_time = sanitize_text_field($_POST['mandator_reaction_time']);
            $mandator_reminder_time = sanitize_text_field($_POST['mandator_reminder_time']);
            if (self::is_wpemergency_trusty_plugin_active()) {
                $trustees_reminder_time = sanitize_text_field($_POST['trustees_reminder_time']);
            }
            $settingsHaveBeenUpdated = false;

            if ($jobSettings !== false) {
                if ($jobSettings['live_status_holdA_noFeedbackTime'] !== $mandator_reaction_time
                    || $jobSettings['live_status_finalHoldA_reminderTime'] !== $mandator_reminder_time
                    || $jobSettings['live_status_finalHoldB_reactionTimeTrustees'] == $trustees_reminder_time) {
                    $settingsHaveBeenUpdated = true;

                    // Client
                    $jobSettings['live_status_holdA_noFeedbackTime'] = $mandator_reaction_time;
                    $jobSettings['live_status_finalHoldA_reminderTime'] = $mandator_reminder_time;
                    $jobSettings['live_status_holdA_reminderTime'] = $mandator_reminder_time;
                    $jobSettings['live_status_holdB_time_periode'] = $mandator_reaction_time;

                    if (self::is_wpemergency_trusty_plugin_active()) {
                        $jobSettings['live_status_finalHoldB_reactionTimeTrustees'] = $trustees_reminder_time;
                        $jobSettings['live_status_noReactionsA_reactionTimeTrustees'] = $trustees_reminder_time;
                        $jobSettings['live_status_finalHoldD_response_periode'] = $trustees_reminder_time;
                        $jobSettings['live_status_finalHoldB_minResponseTrustees'] = $trustees_reminder_time;
                    }
                    update_option('emergencyWP_job_settings', $jobSettings);
                }
            } else {

                if (self::is_wpemergency_trusty_plugin_active()) {
                    $jobSettings = array(
                        // Client
                        'live_status_holdA_noFeedbackTime' => $mandator_reaction_time,
                        'live_status_finalHoldA_reminderTime' => $mandator_reminder_time,
                        'live_status_holdA_reminderTime' => $mandator_reminder_time,
                        'live_status_holdB_time_periode' => $mandator_reaction_time,
                        // Trustees

                        'live_status_finalHoldB_reactionTimeTrustees' => $trustees_reminder_time,
                        'live_status_noReactionsA_reactionTimeTrustees' => $trustees_reminder_time,
                        'live_status_finalHoldD_response_periode' => $trustees_reminder_time,
                        'live_status_finalHoldB_minResponseTrustees' => $trustees_reminder_time,
                    );
                } else {
                    $jobSettings = array(
                        // Client
                        'live_status_holdA_noFeedbackTime' => $mandator_reaction_time,
                        'live_status_finalHoldA_reminderTime' => $mandator_reminder_time,
                        'live_status_holdA_reminderTime' => $mandator_reminder_time,
                        'live_status_holdB_time_periode' => $mandator_reaction_time,
                    );
                }
                add_option('emergencyWP_job_settings', $jobSettings);
                $settingsHaveBeenUpdated = true;
            }
        }
        $lifeCheckFrequencyKey = $jobSettings['live_status_holdA_noFeedbackTime'];
        $lifeCheckReminderTimeKey = $jobSettings['live_status_finalHoldA_reminderTime'];

        $visibility = 1;
        if (isset($widgetsVisibility[$widgetName])) {
            $visibility = $widgetsVisibility[$widgetName];
        }
        $timeZoneString = "Europe/Berlin";
        $timeZoneOption = get_option('timezone_string');
        if (!empty($timeZoneOption)) {
            $timeZoneString = $timeZoneOption;
        }
        if ($debug) {
            var_dump($widgetName);
        }
        switch ($widgetName) {
            case DashboardWidgets::SETTINGS:
            {
                ?>
                <div class="info-box" id="ewp-settings">
                    <div class="header"><?php echo __('Life check frequency', 'emergencywp'); ?><span
                                class="dashicons dashicons-arrow-down info-box-toggle"></span></div>
                    <div class="content stats" style="<?php echo ($visibility == 1) ? '' : 'display:none'; ?>">
                        <img class="icon"
                             src="<?php echo WP_CONTENT_URL; ?>/plugins/emergencywp/assets/images/icons8-slider.png"
                             width="100" alt="life check"/>
                        <div class="number">
                            <?php if ($settingsHaveBeenUpdated) { ?>
                                <div class="ewp-notice -success ewp-success-message">
                                    <p id="content"><?php echo __('Settings updated successfully!', 'emergencywp'); ?></p>
                                </div>
                            <?php } ?>
                            <form id="emergencywp_dasboard-settings-form" method="post"
                                  action="<?php echo get_admin_url(); ?>"
                                  method="post" autocomplete="off">

                                <label class="ewp-widget-label ewp-settings-mandator-reaction"><?php echo __('Life check frequency', 'emergencywp'); ?></label>
                                <select class="form-control ewp-settings-mandator-reaction"
                                        name="mandator_reaction_time" id="exampleInputAmount">
                                    <?php
                                    $mandatorReactionOptions = emergencyWPAdmin::$mandatorReactionOptions;
                                    $mandatorReactionOptions = apply_filters('wpEmergency_life_check_frequency', $mandatorReactionOptions);
                                    foreach ($mandatorReactionOptions as $sec => $option) {
                                        $selected = '';
                                        if ($sec == $jobSettings['live_status_holdA_noFeedbackTime']) {
                                            $selected = ' selected="selected"';
                                        }
                                        echo '			<option value="' . esc_attr($sec) . '"' . esc_attr($selected) . '>' . esc_attr($option) . '</option>';
                                    }
                                    ?>
                                </select>

                                <label class="ewp-widget-label ewp-settings-mandator-reminder"><?php echo __('Timeframe for confirmation (reaction time)', 'emergencywp'); ?></label>
                                <select class="form-control ewp-settings-mandator-reminder"
                                        name="mandator_reminder_time" id="exampleInputAmount">
                                    <?php
                                    $reminderOptions = emergencyWPAdmin::$reminderOptions;
                                    $reminderOptions = apply_filters('wpEmergency_reminder_options', $reminderOptions);
                                    foreach ($reminderOptions as $sec => $option) {
                                        $selected = '';
                                        if ($sec == $jobSettings['live_status_finalHoldA_reminderTime']) {
                                            $selected = ' selected="selected"';
                                        }
                                        echo '			<option value="' . esc_attr($sec) . '"' . esc_attr($selected) . '>' . esc_attr($option) . '</option>';
                                    }
                                    ?>
                                </select>
                                <?php if (self::is_wpemergency_trusty_plugin_active()) {

                                    $trusteesReminderOptions = array(
                                        '172800' => __('2 days minimum', 'emergencywp-trustees'),
                                        '345600' => __('4 days minimum', 'emergencywp-trustees'),
                                        '604800' => __('7 days minimum', 'emergencywp-trustees'),
                                        '3600' => __('1 hour (testing!)', 'emergencywp-trustees'),
                                        '120' => __('2 minutes minimum (testing!)', 'emergencywp-trustees')
                                    );
                                    ?>
                                    <label class="ewp-widget-label ewp-trustees_reminder_time"><?php echo __('Trustees reaction timeframe', 'emergencywp-trustees'); ?></label>
                                    <select class="form-control ewp-trustees_reminder_time"
                                            name="trustees_reminder_time" id="exampleInputAmount">
                                        <?php
                                        foreach ($trusteesReminderOptions as $sec => $option) {
                                            $selected = '';
                                            if ($sec == $jobSettings['live_status_finalHoldB_reactionTimeTrustees']) {
                                                $selected = ' selected="selected"';
                                            }
                                            ?>
                                            <option value="<?php echo esc_attr($sec); ?>" <?php echo esc_attr($selected); ?>><?php echo esc_attr($option); ?></option>
                                            <?php
                                        }
                                        ?>
                                    </select>
                                <?php } ?>
                                <div class="submit-actions">
                                    <br>
                                    <button class="button button-primary" name="settings-dashboard-save" value="save"
                                            type="submit"><?php echo __('Save', 'emergencyWP'); ?></button>
                                </div>

                            </form>
                        </div>
                    </div>
                </div>
                <?php
                break;
            }
            case DashboardWidgets::LIFE_CHECK :
            {
                ?>
                <div class="info-box" id="ewp-lifecheck">
                    <div class="header"><?php echo __('Lifecheck frequency', 'emergencywp'); ?><span
                                class="dashicons dashicons-arrow-down info-box-toggle"></span></div>
                    <div class="content stats" style="<?php echo ($visibility == 1) ? '' : 'display:none'; ?>">
                        <img class="icon"
                             src="<?php echo WP_CONTENT_URL; ?>/plugins/emergencywp/assets/images/icons8-life_check_frequency.png"
                             width="100" alt="life check"/>

                        <div class="number">
                            <p><?php echo __('every', 'emergencywp'); ?>
                                <span class="no"><?php echo LifeCheck::getLifeCheckFrequency($lifeCheckFrequencyKey); ?></span>
                            </p>
                        </div>
                    </div>
                </div>
                <?php
                break;
            }
            case DashboardWidgets::CONTACTS :
            {
                $contacts = get_posts('post_type=emergencywp_contacts&post_status=any');
                $contactsCount = count($contacts);
                ?>
                <div class="info-box" id="ewp-contacts">
                    <div class="header"><?php echo __('Сontacts', 'emergencywp'); ?><span
                                class="dashicons dashicons-arrow-down info-box-toggle"></span></div>
                    <div class="content stats" style="<?php echo ($visibility == 1) ? '' : 'display:none'; ?>">
                        <img class="icon"
                             src="<?php echo WP_CONTENT_URL; ?>/plugins/emergencywp/assets/images/icons8-contacts.png"
                             width="100" alt="contacts"/>
                        <div class="number">
                            <p>
                                <?php
                                printf(_n('%s contact', '%s contacts', $contactsCount, 'emergencywp'), '<span class="no">' . number_format_i18n($contactsCount) . '</span>');
                                ?>
                            </p>
                        </div>
                        <div class="ewp_button-container">
                            <a class="widget button button-primary waves-effect waves-light"
                               href="/wp-admin/admin.php?post_type=emergencywp_contacts&page=emergencywp_contacts&new"><?php echo __('New', 'emergencywp'); ?></a>
                            <a class="widget button button-view waves-effect waves-light"
                               href="/wp-admin/admin.php?page=emergencywp_contacts"><?php echo __('View', 'emergencywp'); ?></a>
                        </div>
                    </div>
                </div>
                <?php
                break;
            }
            case DashboardWidgets::MESSAGES :
            {
                $messages = get_posts('post_type=emergencywp_messages&post_status=any');
                $messagesCount = count($messages);
                ?>
                <div class="info-box" id="ewp-messages">
                    <div class="header"><?php echo __('Messages', 'emergencywp'); ?><span
                                class="dashicons dashicons-arrow-down info-box-toggle"></span></div>
                    <div class="content stats" style="<?php echo ($visibility == 1) ? '' : 'display:none'; ?>">
                        <img class="icon"
                             src="<?php echo WP_CONTENT_URL; ?>/plugins/emergencywp/assets/images/icons-messages.png"
                             width="100" alt="messages"/>

                        <div class="number">
                            <p>
                                <?php
                                printf(_n('%s message', '%s messages', $messagesCount, 'emergencywp'), '<span class="no">' . number_format_i18n($messagesCount) . '</span>');
                                ?>
                            </p>
                            <div class="ewp_button-container">
                                <a class="widget button button-primary waves-effect waves-light"
                                   href="/wp-admin/post-new.php?post_type=emergencywp_messages"><?php echo __('New', 'emergencywp'); ?></a>
                                <a class="widget button button-view waves-effect waves-light"
                                   href="/wp-admin/edit.php?post_type=emergencywp_messages"><?php echo __('View', 'emergencywp'); ?></a>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
                break;
            }
            case DashboardWidgets::TRUSTEES :
            {
                if (emergencyWPAdmin::is_wpemergency_trusty_plugin_active()) {
                    $trustees = get_posts('post_type=emergencywp_trustees&post_status=any');
                    $trusteesCount = count($trustees);
                    ?>
                    <div class="info-box" id="ewp-trustees">
                        <div class="header"><?php echo __('Trustees', 'emergencywp'); ?><span
                                    class="dashicons dashicons-arrow-down info-box-toggle"></span></div>
                        <div class="content stats" style="<?php echo ($visibility == 1) ? '' : 'display:none'; ?>">
                            <img class="icon"
                                 src="<?php echo WP_CONTENT_URL; ?>/plugins/emergencywp/assets/images/icons8-trustees.png"
                                 width="100" alt="messages"/>
                            <div class="number">
                                <p>
                                    <?php
                                    printf(_n('%s person', '%s people', $trusteesCount, 'emergencywp'), '<span class="no">' . number_format_i18n($trusteesCount) . '</span>');
                                    ?>
                                </p>
                                <div class="ewp_button-container">
                                    <a class="widget button button-view waves-effect waves-light"
                                       href="/wp-admin/admin.php?page=emergencywp_trustees"><?php echo __('View', 'emergencywp'); ?></a>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php
                }
                break;
            }
            case DashboardWidgets::LAST_LIFE_CHECK :
            {
                $datetime = new DateTime();
                $interval = $lastLifeCheck->diff($datetime);

                $lastLifeCheck->setTimezone(new DateTimeZone($timeZoneString));
                if ($debug) {
                    var_dump($interval);
                }
                ?>
                <div class="info-box" id="ewp-lastlifecheck">
                    <div class="header"><?php echo __('Last Lifecheck', 'emergencywp'); ?><span
                                class="dashicons dashicons-arrow-down info-box-toggle"></span></div>
                    <div class="content stats" style="<?php echo ($visibility == 1) ? '' : 'display:none'; ?>">
                        <img class="icon"
                             src="<?php echo WP_CONTENT_URL; ?>/plugins/emergencywp/assets/images/icons8-last_life_check.png"
                             width="100" alt="messages"/>
                        <div class="info-content">
                            <div class="number">
                                <p>
                                    <?php
                                    $value = $interval->format('%a');
                                    printf(_n('%s day ago', '%s days ago', abs($value), 'emergencywp'), '<span class="no">' . number_format_i18n(abs($value)) . '</span>');
                                    ?>
                                </p>
                            </div>
                            <p class="ewp-info">
                                <?php
                                if ($debug) {
                                    echo 'getDateFormat' . emergencyWPAdmin::getDateFormat();
                                    echo 'getTimeFormat' . emergencyWPAdmin::getTimeFormat();
                                }
                                ?>
                            <div class="date-text time"><?php echo esc_html($lastLifeCheck->format(emergencyWPAdmin::getDateFormat())); ?> <?php echo esc_html($lastLifeCheck->format(emergencyWPAdmin::getTimeFormat())); ?></div>
                            </p>
                        </div>
                    </div>
                </div>
                <?php
                break;
            }
            case DashboardWidgets::NEXT_LIFE_CHECK :
            {
                $jobSettings = get_option('emergencyWP_job_settings');
                $nextLifeCheckTimestamp = $lastLifeCheck->getTimestamp() + $jobSettings['live_status_holdA_noFeedbackTime'];
                $nextLifeCheck = new DateTime();
                $nextLifeCheck->setTimestamp($nextLifeCheckTimestamp);
                $nextLifeCheck->setTimezone(new DateTimeZone($timeZoneString));

                $datetime = new DateTime();
                $interval = $datetime->diff($nextLifeCheck);
                ?>
                <div class="info-box" id="ewp-nextlifecheck">
                    <div class="header"><?php echo __('Next Lifecheck', 'emergencywp'); ?><span
                                class="dashicons dashicons-arrow-down info-box-toggle"></span></div>
                    <div class="content stats" style="<?php echo ($visibility == 1) ? '' : 'display:none'; ?>">
                        <img class="icon"
                             src="<?php echo WP_CONTENT_URL; ?>/plugins/emergencywp/assets/images/icons8-next_life_check.png"
                             width="100" alt="messages"/>
                        <div class="info-content">
                            <div class="number">
                                <p>
                                    <?php
                                    $value = $interval->format('%R%a');
                                    if ($value < 0) {
                                        printf(_n('%s day ago', '%s days ago', abs($value), 'emergencywp'), '<span class="no">' . number_format_i18n(abs($value)) . '</span>');
                                    } else {
                                        printf(_n('in %s day', 'in %s days', $value, 'emergencywp'), '<span class="no">' . number_format_i18n($value) . '</span>');
                                    }
                                    ?>
                                </p>
                            </div>
                            <p class="ewp-info">
                            <div class="date-text time"><?php echo $nextLifeCheck->format(emergencyWPAdmin::getDateFormat()); ?> <?php echo $nextLifeCheck->format(emergencyWPAdmin::getTimeFormat()); ?></div>
                            </p>
                        </div>
                    </div>
                </div>
                <?php
                break;
            }
            case DashboardWidgets::REACTION_TIME_FRAME :
            {
                ?>
                <div class="info-box" id="<?php echo DashboardWidgets::REACTION_TIME_FRAME; ?>">
                    <div class="header"><?php echo __('Confirmation timeframe', 'emergencywp'); ?><span
                                class="dashicons dashicons-arrow-down info-box-toggle"></span></div>
                    <div class="content stats" style="<?php echo ($visibility == 1) ? '' : 'display:none'; ?>">
                        <img class="icon"
                             src="<?php echo WP_CONTENT_URL; ?>/plugins/emergencywp/assets/images/icons8-reaction-time.png"
                             width="100" alt="reaction time"/>

                        <div class="number">
                            <p>
                                <span class="no"><?php echo LifeCheck::getReactionTime($lifeCheckReminderTimeKey); ?></span>
                            </p>
                            <div class="explain-text"><?php echo __('Confirm your life checks within this time.', 'emergencywp'); ?></div>
                        </div>
                    </div>
                </div>
                <?php
                break;
            }
            default :
            {
                break;
            }
        }
    }

    public static function getMandatorID()
    {
        $mandatorData = emergencyWPAdmin::getMandatorData(get_current_blog_id());
        if (!isset($mandatorData['id'])) {
            $args = [
                'orderby' => 'ID',
                'order' => 'ASC',
                'role' => 'administrator',
                'user_email' => $mandatorData['email']
            ];
            $users = get_users($args);

            $mandatorData['id'] = $users[0]->ID;
            return $mandatorData['id'];
        } else {
            return $mandatorData['id'];
        }
    }

    static function ewp_login_redirect()
    {
        if (!defined('DOING_AJAX')) {
            //is there a user to check?
            $user = wp_get_current_user();
            if (isset($user->roles) && is_array($user->roles)) {
                //check for subscribers
                if (in_array('subscriber', $user->roles)) {
                    // redirect them to another URL, in this case, the homepage
                    //check if user is a contact
                    if (class_exists('emergencyWPContacts')) {
                        $args = array(
                            'post_type' => emergencyWPContacts::$postTypeSlug,
                            'post_status' => 'publish',
                            'posts_per_page' => -1,

                            'meta_query' => array(
                                'relation' => 'AND',
                                array(
                                    'key' => emergencyWPContacts::$postTypeSlug . '_email',
                                    'value' => $user->user_email
                                ),
                            ),
                        );
                        $ewp_contacts = get_posts($args);
                        if (count($ewp_contacts) > 0) {
                            wp_redirect(home_url() . '/ewp-vault-items/');
                        }
                    }
                }
            }
        }
    }

    static function ewp_header_script() {
        global $wp;
        if(strpos($wp->request, 'ewp-sign-up') > 0 || strpos($wp->request, 'ewp-emergency') > 0 || $wp->request == 'ewp-sign-up' || $wp->request == 'ewp-emergency') {
            if (self::is_wpemergency_vault_plugin_active() || self::is_wpemergency_vault_plugin_active()) {
                wp_register_script("recaptcha", "https://www.google.com/recaptcha/api.js");
                    wp_enqueue_script("recaptcha");
            }
        }
    }

    public static function ewp_ajax_resetAliveStatus() {
        include(EMERGENCY_WP_PLUGIN_DIR . "ajax/resetAliveStatus.php");
        exit();
    }

    public static function emergencywp_send_test_email(){
	    include(EMERGENCY_WP_PLUGIN_DIR . 'cron/cron_config.php');
	    emergencyWPJobController::sendTestEmailToClient(intval($_POST['blogId']));
	    exit();
    }
}


?>