<?php


class emergencyWPContacts
{

    static $postTypeSlug = "emergencywp_contacts";
    static $className = "emergencyWPContacts";

    public function __construct()
    {
        add_action('plugins_loaded', array(&$this, 'init'));
    }

    public function init()
    {
        add_action('emergencywp_additional_menus',array(&$this, 'admin_menu'), 10);
        add_action('add_meta_boxes', array(&$this, 'my_remove_wp_seo_meta_box'), 100);
    }

    function my_remove_wp_seo_meta_box()
    {
        remove_meta_box('wpseo_meta', self::$postTypeSlug, 'normal');
    }

    public function admin_menu()
    {
        $minCapability = emergencyWPAdmin::getMinCapability();
        $page = add_submenu_page(
            'emergencywp',
            __('Contacts', 'emergencywp'),
            __('Contacts', 'emergencywp'),
            $minCapability,
            'emergencywp_contacts',
            array('emergencyWPContacts', 'view_contacts'));

        $page = add_submenu_page(
            'admin.php?post_type=emergencywp_contacts',
            __('Contacts', 'emergencywp'),
            __('Contacts', 'emergencywp'),
            $minCapability,
            'emergencywp_contacts',
            array('emergencyWPContacts', 'view_contacts'));

        if (isset($_GET['ID']) || isset($_GET['new'])) {
            add_action('load-'.$page, array(&$this, 'edit_entry'), 99);
        }
    }

    public function edit_entry()
    {
        global $post;
        if (isset($_POST) && count($_POST) > 0) {
            $e = 0;
            if (strlen(sanitize_text_field($_POST[self::$postTypeSlug . '_lastName'])) <= 2) {
                emergencyWPAdmin::setAdminNotice('error', emergencyWPContacts::$postTypeSlug, __('Please add a last name (min. 2 characters)', 'emergencywp')); //'Please enter first name');
                $e++;
            }

            // Email
            $_POST[self::$postTypeSlug . '_email'] = str_replace(array(' '), '', sanitize_email($_POST[self::$postTypeSlug . '_email']));
            if (!is_email(sanitize_text_field($_POST[self::$postTypeSlug . '_email']))) {
                emergencyWPAdmin::setAdminNotice('error',  emergencyWPContacts::$postTypeSlug, __('Please provide a valid e-mail address.', 'emergencywp'));
                $e++;
            }

            if ($e == 0) {
                if (isset($_POST['publish'])) {
                    if (isset($_GET['new'])) {
                        // Create post object
                        $my_post = array(
                            'post_type' => 'emergencywp_contacts',
                            'post_status' => 'publish'
                        );

                        // Insert the post into the database
                        if (intval(emergencyWPAdmin::getContactLimit()) < intval(emergencyWPContacts::getNumbersOfPosts())) {
                            $notices = get_option('emergencywp_error_notices');
                            $short_code = EWP_ShortCodes::JOB_HANDLER;
                            if(!is_array($notices)){
                                $notices = array();
                            } else if(isset($notices['emergencywp_contact_limit_exceeded' ])){
                                unset($notices['emergencywp_contact_limit_exceeded' ]);
                            }
                            $notices['emergencywp_contact_limit_exceeded' ][] = __('You have reached the maximum number of contacts. Please upgrade to PRO version to have unlimited contacts!','emergencywp' );

                            update_option('emergencywp_error_notices',$notices);
                            return 0;
                        } else {
                            $id = wp_insert_post($my_post);
                            $saved_id = emergencyWPContacts::saveCustomPostTypeInfo($id);

                            if ($saved_id != false) {
                                wp_redirect('admin.php?page=emergencywp_contacts');
                            }
                        }
                    } else {
                        $my_post = array(
                            'ID' => sanitize_text_field($_GET['ID']),
                            'post_status' => 'publish'
                        );
                        wp_update_post($my_post);
                        $saved_id = emergencyWPContacts::saveCustomPostTypeInfo(sanitize_text_field($_GET['ID']));
                    }
                }
            }
        }
    }

    public static function initPostType()
    {
        self::customPostType();
    }

    public static function customPostType()
    {
        register_post_type(self::$postTypeSlug,
            array(
                "public" => true,
                "menu_icon" => "dashicons-universal-access",
                "labels" => array(
                    "name" => __('Contacts', 'emergencywp'),
                    "singular_name" => __('Contact', 'emergencywp'),
                    "add_new" => __('Add New', 'emergencywp'),
                    "add_new_item" => __('Add New Contact', 'emergencywp'),
                    "edit" => __('Edit', 'emergencywp'),
                    "edit_item" => __('Edit Contact', 'emergencywp'),
                    "new_item" => __('New Contact', 'emergencywp'),
                    "view" => __('View Contact', 'emergencywp'),
                    "view_item" => __('View Contact', 'emergencywp'),
                    "search_items" => __('Search Contact', 'emergencywp'),
                    "not_found" => __('No Contacts Found', 'emergencywp'),
                    "not_found_in_trash" => __('No Contacts Found in trash', 'emergencywp'),
                    "parent" => __(self::$postTypeSlug),
                ),
                "show_in_menu" => false,
                "menu_position" => 101,
                "supports" => array(
                    "custom_fields",
                ),
            )
        );
    }

    public static function view_contacts()
    {
        global $pagenow;

        if (isset($_POST['action']) && sanitize_text_field($_POST['action']) == 'emergencywp_contacts_delete') {
            if (isset($_POST['bulk-delete']) && is_array($_POST['bulk-delete'])) {
                foreach ($_POST['bulk-delete'] AS $deletePostID) {
                    $nonce = sanitize_text_field( $_REQUEST['_wpnonce'] );
                    if ( ! wp_verify_nonce( $nonce, 'emergencywp_contacts' ) ) {
                        wp_delete_post(sanitize_key($deletePostID));
                    }
                }
            }
        }

        if (isset($_GET['action']) && sanitize_key($_GET['action']) == 'trash') {

            if (isset($_GET['post'])) {
                wp_trash_post(intval($_GET['post']));
            }

            self::showOverview();
        } else if (isset($_GET['action']) && sanitize_key($_GET['action']) == 'delete') {

            if (isset($_GET['post'])) {
                wp_delete_post(intval($_GET['post']));
            }

            self::showOverview('trash');
        } else {
            if (isset($_GET['post']) || isset($_GET['new'])) {

                include EMERGENCY_WP_PLUGIN_DIR . 'views/contacts/detail.php';

            } else {

                self::showOverview();

            }
        }
    }

    public static function showOverview($status = '')
    {
        require_once EMERGENCY_WP_PLUGIN_DIR . 'lib/class.emergencyWPContactsTables.php';
        include EMERGENCY_WP_PLUGIN_DIR . 'views/contacts/overview.php';
    }

    public static function saveCustomPostTypeInfo($post_id)
    {
        global $post;

        // verify nonce
        if (!wp_verify_nonce(sanitize_key(@$_POST['custom_meta_box_nonce']), 'class.emergencyWPContacts.details')) {
            return $post_id;
        }
        // check autosave
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return $post_id;
        }
        // check permissions
        if(!current_user_can(emergencyWPAdmin::getMinCapability())){
            return $post_id;
        }
        $e = 0;

        // FirstName
        self::saveMetaValueData(self::$postTypeSlug . '_firstName', $post_id);

        // LastName
        self::saveMetaValueData(self::$postTypeSlug . '_lastName', $post_id);
        if (strlen(sanitize_text_field($_POST[self::$postTypeSlug . '_lastName'])) <= 2) {
            emergencyWPAdmin::setAdminNotice('error',  emergencyWPContacts::$postTypeSlug, __('Please add a last name (min. 2 characters)', 'emergencywp')); //'Please enter first name');
            $e++;
        }

        // Address
        self::saveMetaValueData(self::$postTypeSlug . '_address', $post_id);
        self::saveMetaValueData(self::$postTypeSlug . '_countryCode', $post_id);

        // Email
        // replace some illegal signs - email address
        $_POST[self::$postTypeSlug . '_email'] = str_replace(array(' '), '', sanitize_email($_POST[self::$postTypeSlug . '_email']));
        self::saveMetaValueData(self::$postTypeSlug . '_email', $post_id);
        if (!is_email(sanitize_email($_POST[self::$postTypeSlug . '_email']))) {
            emergencyWPAdmin::setAdminNotice('error',  emergencyWPContacts::$postTypeSlug, __('Please provide a valid e-mail address.', 'emergencywp'));
            $e++;
        }
//var_dump($e); exit();
        // Mobile
        self::saveMetaValueData(self::$postTypeSlug . '_mobile', $post_id);

        // contactImage
        //self::saveMetaValueData( self::$postTypeSlug . '_contactImgae', $post_id );


        if ($e > 0) {
            return false;
        } else {
            if ($post->post_status === 'auto-draft') {
                emergencyWPAdmin::setAdminNotice('updated',  emergencyWPContacts::$postTypeSlug, __('A new contact has been created.', 'emergencywp'));
            } else {
                emergencyWPAdmin::setAdminNotice('updated',  emergencyWPContacts::$postTypeSlug, __('The contact was updated successfully.', 'emergencywp'));
            }

            return true;
        }
    }

    private static function saveMetaValueData($post_meta_key, $pId)
    {
        if (!is_numeric($pId)) {
            return false;
        }

        $meta_value_new = sanitize_text_field($_POST[$post_meta_key]);
        $meta_value_old = get_post_meta($pId, $post_meta_key, true);

        if ($meta_value_new && $meta_value_new != $meta_value_old) {
            update_post_meta($pId, $post_meta_key, $meta_value_new);
        } elseif ('' == $meta_value_new && $meta_value_old) {
            delete_post_meta($pId, $meta_value_new, $saved);
        }
    }

    public static function getNumbersOfPosts(){
        global $wpdb;

        /* -- Preparing your query -- */
        $query = "SELECT * FROM $wpdb->posts WHERE post_type = 'emergencywp_contacts' ";
        return $wpdb->query( $query );
    }
}

?>