<?php

defined('ABSPATH') or die("No script kiddies please!");

if (!class_exists('emergencyWPJobController')) {

    class emergencyWPJobController
    {
        public static $blogId;

        // list of all possible Jobs
        public static $allJobTypes = array(
            'alive',
            'holdA',
            'holdB',
            'finalHoldA',
            'finalHoldA',
            'finalHoldB',
            'finalHoldC',
            'finalHoldCTrusteesInfo',
            'finalHoldCMandator',
            'finalHoldCTrusteesConfirm',
            'finalHoldD',
            'noReactionsA',
            'noReactionsB',
            'unknown',
            'dead'
        );
        // all Jobs where are reponses required
        public static $trusteesResponseJobs = array('finalHoldB', 'noReactionsA', 'finalHoldC', 'finalHoldD');

        public static function setAliveStatus($newStatus = null, $source = 'email', $message = '')
        {
            if (is_null($newStatus)) return;


            $aliveInfo = $status = emergencyWPJobController::getAliveStatus();
            $changed = false;

            switch ($newStatus) {
                case UserStatus::ALIVE:
                    EWP_initPluginVars::setAliveStatusVar();
                    EWP_initPluginVars::$aliveStatus['lastFeedback'] = date('Y-m-d H:i:s', time());
                    EWP_initPluginVars::$aliveStatus['passThroughKey'] = ewp_getPassThroughKey();
                    EWP_initPluginVars::$aliveStatus['mandatorKey'] = $aliveInfo['mandatorKey'];
                    self::updateOption('emergencyWP_alive_status', EWP_initPluginVars::$aliveStatus);

                    if(class_exists('EmergencyWPAliveConfirmationLog')){
                        EmergencyWPAliveConfirmationLog::saveConfirmationLog($source, $message);
                    }

                    break;
                case UserStatus::HOLD_A:
                    $status['jobStatus'] = UserStatus::HOLD_A;
                    $status['jobEmails'][UserStatus::HOLD_A] = time();
                    $changed = true;
                    break;
                case UserStatus::HOLD_B:
                    $status['jobStatus'] = UserStatus::HOLD_B;
                    $status['jobEmails'][UserStatus::HOLD_B] = '';
                    $status['jobEmails'][UserStatus::FINAL_HOLD_D] = '';
                    $status['trustyFeedback'][UserStatus::FINAL_HOLD_D]['all'] = array();
                    $status['trustyFeedback'][UserStatus::FINAL_HOLD_D]['alive'] = array();
                    $status['trustyFeedback'][UserStatus::FINAL_HOLD_D]['dead'] = array();
                    $changed = true;
                    break;
                case UserStatus::FINAL_HOLD_A:
                    if($status['jobStatus'] != UserStatus::FINAL_HOLD_A){
                        do_action('emergencywp_mandator_before_final_holdA');
                    }
                    $status['jobStatus'] = UserStatus::FINAL_HOLD_A;
                    $status['jobEmails'][UserStatus::FINAL_HOLD_A] = time();
                    $changed = true;

                    break;
                case UserStatus::FINAL_HOLD_B:
                    $status['jobStatus'] = UserStatus::FINAL_HOLD_B;
                    $status['jobEmails'][UserStatus::FINAL_HOLD_B] = time();
                    $changed = true;
                    break;
                case UserStatus::FINAL_HOLD_C:
                    $status['jobStatus'] = UserStatus::FINAL_HOLD_C;
                    $status['jobEmails'][UserStatus::FINAL_HOLD_C_TRUSTEES_INFO] = '';
                    $status['jobEmails'][UserStatus::FINAL_HOLD_C_MANDATOR] = '';
                    $status['jobEmails'][UserStatus::FINAL_HOLD_C_TRUSTEES_CONFIRM] = '';
                    $status['trustyFeedback'][UserStatus::FINAL_HOLD_C]['iteration']++;
                    $status['trustyFeedback'][UserStatus::FINAL_HOLD_C]['all'] = array();
                    $status['trustyFeedback'][UserStatus::FINAL_HOLD_C]['alive'] = array();
                    $status['trustyFeedback'][UserStatus::FINAL_HOLD_C]['dead'] = array();
                    $changed = true;
                    break;
                case UserStatus::FINAL_HOLD_C_TRUSTEES_INFO:
                    $status['jobEmails'][UserStatus::FINAL_HOLD_C_TRUSTEES_INFO] = time();
                    $changed = true;
                    break;
                case UserStatus::FINAL_HOLD_C_MANDATOR:
                    $status['jobEmails'][UserStatus::FINAL_HOLD_C_MANDATOR] = time();
                    $changed = true;
                    break;
                case UserStatus::FINAL_HOLD_C_TRUSTEES_CONFIRM:
                    $status['jobEmails'][UserStatus::FINAL_HOLD_C_TRUSTEES_CONFIRM] = time();
                    $changed = true;
                    break;
                case UserStatus::FINAL_HOLD_D:
                    $status['jobStatus'] = UserStatus::FINAL_HOLD_D;
                    $status['jobEmails'][UserStatus::FINAL_HOLD_D] = time();
                    $changed = true;
                    break;
                case UserStatus::NO_REACTIONS_A:
                    $status['jobStatus'] = UserStatus::NO_REACTIONS_A;
                    $changed = true;
                    break;
                case UserStatus::NO_REACTIONS_B:
                    $status['jobStatus'] = UserStatus::NO_REACTIONS_B;
                    $changed = true;
                    break;
                    break;

                case UserStatus::EMERGENCY_EMAIL:
                    $status['jobStatus'] = UserStatus::EMERGENCY_EMAIL;
                    $status['jobEmails'][UserStatus::EMERGENCY_EMAIL] = time();
                    $changed = true;
                    break;

                case UserStatus::UNKNOWN:
                    $status['jobStatus'] = UserStatus::UNKNOWN;
                    $status['jobEmails'][UserStatus::UNKNOWN] = time();
                    $changed = true;
                    break;
                case UserStatus::DEAD:
                    if($status['jobStatus'] != UserStatus::DEAD){
                        do_action('emergencywp_mandator_before_process_finished');
                    }
                    $status['jobStatus'] = UserStatus::DEAD;
                    $status['jobEmails'][UserStatus::DEAD] = time();
                    $changed = true;

                    break;
                case 'messages':
                    $status['jobEmails']['messages'] = time();
                    $changed = true;
                default:
            }

            if ($changed) {
                self::updateOption('emergencyWP_alive_status', $status);
            }
        }

        public static function getActiveTrustees($single = true)
        {

            $trustees = array();
            $args = array(
                'posts_per_page' => 20,
                'offset' => 0,
                'category' => '',
                'category_name' => '',
                'orderby' => 'post_date',
                'order' => 'DESC',
                'include' => '',
                'exclude' => '',
                'meta_key' => '',
                'meta_value' => '',
                'post_type' => 'emergencywp_trustees',
                'post_mime_type' => '',
                'post_parent' => '',
                'suppress_filters' => true);

            $trustyData = emergencyWPAdmin::getWpPost($args);
            if ($trustyData !== false) {
                foreach ($trustyData as $k => $trusty) {
                    $trustyPostMeta = emergencyWPAdmin::getWpPostMeta($trusty->ID);

                    if ($trustyPostMeta['emergencywp_trustees_status'][0] === "approved") {
                        $trustySinglePostMeta = array();
                        if ($single === true) {
                            foreach ($trustyPostMeta as $key => $v) {
                                $trustySinglePostMeta[$key] = $v[0];
                            }
                        } else $trustySinglePostMeta = $trustyPostMeta;
                        $trustees[] = array(
                            'post' => $trusty,
                            'postMeta' => $trustySinglePostMeta
                        );
                    }
                }
            } else {
                echo "FALSE";
            }
            return $trustees;
        }

        public static function getTrusteesWithResponse($jobStatus = null)
        {

            $trustyWithResponse = array();

            if (is_null($jobStatus)) return $trustyWithResponse;

            $aliveStatus = emergencyWPJobController::getAliveStatus();

            $jobs = array($jobStatus);
            if ($jobStatus === UserStatus::FINAL_HOLD_D) {
                if (strlen($aliveStatus['jobEmails']['noReactionsA']) > 0) array_push($jobs, 'noReactionsA');
                elseif (strlen($aliveStatus['jobEmails']['finalHoldB']) > 0) array_push($jobs, 'finalHoldB');
            }

            $checkAliveStatus = array('alive', 'dead');
            foreach ($checkAliveStatus as $aStatus) {
                foreach ($jobs as $job) {
                    if (count(@$aliveStatus['trustyFeedback'][$job][$aStatus])) {
                        foreach ($aliveStatus['trustyFeedback'][$job][$aStatus] as $tId => $timestamp) {
                            $trustySinglePostMeta = array();
                            $trustyPostMeta = emergencyWPAdmin::getWpPostMeta($tId);
                            foreach ($trustyPostMeta as $key => $v) {
                                $trustySinglePostMeta[$key] = $v[0];
                            }
                            $trustyWithResponse[$tId] = $trustySinglePostMeta;
                        }
                    }
                }
            }
            return $trustyWithResponse;
        }

        public static function getActiveTrusteesCount()
        {
            $t = self::getActiveTrustees();
            return count($t);
        }

        public static function checkTrustyResponse($hash = null, $job = null, $aliveStatus = null)
        {
            if (is_null($hash) || is_null($job) || is_null($aliveStatus)) return -10;
            if (!in_array($job, self::$trusteesResponseJobs)) {
                // unknow JobStatus
                if (!in_array($job, self::$allJobTypes)) return -9;
                // Job is correct, but response out of time
                return -5;

            }

            $aliveInfo = self::getAliveStatus();

            if ($aliveStatus === md5('alive')) $aliveStatus = 'alive';
            else if ($aliveStatus === md5('dead')) $aliveStatus = 'dead';
            else return -6;

            if (!is_array(@$aliveInfo['trustyFeedback'][$job])) return -8; // system Error aliveInfo array corrupted
            if (!count(@$aliveInfo['trustyFeedback'][$job]['all'])) return -11; // Response out of Time

           foreach ($aliveInfo['trustyFeedback'][$job]['all'] as $trusty) {
                //$trustyDBHash = get_post_meta( $trusty['pId'], 'emergencywp_trustees_hashCode', true);
                $trustyDBHash = emergencyWPAdmin::getPostMeta($trusty['pId'], 'emergencywp_trustees_hashCode');
                if ($hash === $trustyDBHash) {
                    if (array_key_exists($trusty['pId'], @$aliveInfo['trustyFeedback'][$job]['alive'])) return -2; // Trusty given already response (alive)
                    else if (array_key_exists($trusty['pId'], @$aliveInfo['trustyFeedback'][$job]['dead'])) return -1; // Trusty given already response (dead)

                    //update_post_meta($trusty['pId'], 'emergencywp_trustees_' . $job . '_response', $aliveStatus );
                    // set aliveInfo
                    $aliveInfo['trustyFeedback'][$job][$aliveStatus][$trusty['pId']] = time();
                    //update_option( 'emergencyWP_alive_status', $aliveInfo );
                    self::updateOption('emergencyWP_alive_status', $aliveInfo);
                    //self::updateOption($key, $value)
                    if ($aliveStatus === 'alive') return 1;
                    else return 2;
                }
            }
            if (in_array($job, self::$allJobTypes)) return -5;
            return -7; // Trusty Hash was not found!

        }

        //public static function checkFeedbackTrustees( $job = 'finalHoldB', $trusteesToCheck = 'all' ){
        public static function checkFeedbackTrustees($job = 'finalHoldB')
        {
            $debug = 1;

            if ($debug) {
                echo "job: " . esc_attr($job) . "<br />";
            }
            $aliveStatus = self::getAliveStatus();
            $jobSettings = self::getJobSettings();

            // check if the given job is active
            if ($debug) {
                echo esc_attr($aliveStatus['jobStatus']) . " !== " . esc_attr($job) . " > return false <br />";
            }
            if ($aliveStatus['jobStatus'] !== $job) return false;

            // get reaction time
            if ($job === UserStatus::FINAL_HOLD_C) {
                // reset reaction time for finalHoldC JobStatus
                $reactionTime = ($aliveStatus['jobEmails']['finalHoldCTrusteesConfirm'] + emergencyWPConfig::$jobFinalHoldCMandatorResponseTime) - time();
            } else {
                $reactionTime = ($aliveStatus['jobEmails'][$job] + $jobSettings['live_status_' . $job . '_reactionTimeTrustees']) - time();
            }

            if ($debug) {
                echo "reactiontime : " . esc_attr($reactionTime) . "<br />";
            }

            $trustees = $aliveStatus['trustyFeedback'][$job];
            if ($debug) {
                echo "trustees<pre>";
                print_r(esc_attr($trustees));
                echo "</pre>";
            }

            $cAllTrustees = count($trustees['all']);
            $cAliveResponsesInTime = self::trustyResponse('alive', $job);
            $cDeadResponsesInTime = self::trustyResponse('dead', $job);

            if ($debug) {
                echo "cAll: " . esc_attr($cAllTrustees) . "<br />";
                echo "cAliveResponsesInTime: " . esc_attr($cAliveResponsesInTime) . "<br />";
                echo "cDeadResponsesInTime: " . esc_attr($cDeadResponsesInTime) . "<br />";
            }

            if ($cAllTrustees === 0) return $job;
            if ($cAllTrustees === $cAliveResponsesInTime) return 'alive';
            if ($cAllTrustees === $cDeadResponsesInTime) return 'dead';
            if ($cAliveResponsesInTime > 0 && $cDeadResponsesInTime == 0) return 'aliveIncomplete';
            if ($cAliveResponsesInTime == 0 && $cDeadResponsesInTime > 0) return 'deadIncomplete';
            if ($cAliveResponsesInTime > 0 && $cDeadResponsesInTime > 0) {
                return 'finalHoldC';
            }
            if ($cAliveResponsesInTime == 0 && $cDeadResponsesInTime == 0 && $reactionTime < 0) {
                if ($job === "finalHoldB") return 'noReactionsA';
                if ($job === "noReactionsA") return 'noReactionsB';
                if ($job === "finalHoldC") return "finalHoldC";
            }
            return $job;
        }

        public static function getTrustyResponseText($status = null, $jobType = null)
        {
            global $initPluginVars;

            $mandatorData = emergencyWPAdmin::getMandatorData(emergencyWPJobController::$blogId);
            $mandatorName = $mandatorData['firstName'] . " " . $mandatorData['lastName'];

            switch ($status) {
                case -11:
                    return __('We are sorry, but your response is out of time. ', 'emergencywp');
                case null:
                    return __('Oops, there is unfortunately a technical error occurred.<br /><br /> ', 'emergencywp') . __('No Status transmitted ', 'emergencywp');
                case -10:
                    return __('Oops, there is unfortunately a technical error occurred.<br /><br /> ', 'emergencywp') . __('Please contact our support! <span class="error-code">[ErrorCode: ERR-JOB-10]</span> ', 'emergencywp');
                case -9:
                    return __('Oops, there is unfortunately a technical error occurred.<br /><br /> ', 'emergencywp') . __('Please contact our support! <span class="error-code">[ErrorCode: ERR-JOB-9]</span> ', 'emergencywp');
                case -8:
                    return __('Oops, there is unfortunately a technical error occurred.<br /><br /> ', 'emergencywp') . __('Please contact our support! <span class="error-code">[ErrorCode: ERR-JOB-8]</span> ', 'emergencywp');
                case -7:
                    return __('Oops, there is unfortunately a technical error occurred.<br /><br /> ', 'emergencywp') . __('We are sorry, but we could not identify your affiliation with reference to the link!<br />Please contact our support! <span class="error-code">[ErrorCode: ERR-JOB-7]</span> ', 'emergencywp');
                case -6:
                    return __('Oops, there is unfortunately a technical error occurred.<br /><br /> ', 'emergencywp') . __('Please contact our support! <span class="error-code">[ErrorCode: ERR-JOB-6]</span> ', 'emergencywp');
                case -5:
                    return __('We are sorry, but your response is out of time. ', 'emergencywp');
                case -2:
                    return __('You have already confirmed the survival status (alive) ', 'emergencywp');
                case -1:
                    return __('You have already confirmed the survival status (death) ', 'emergencywp');
                case 1:
                    return sprintf(__('We are glad to hear that %s is still alive. We have saved your feedback. ', 'emergencywp'), $mandatorName);
                case 2:
                    return sprintf(__('We are very sad to hear that %s has passed away.<br />We wish to express our condolences.<br /><br />Your feedback has been saved. ', 'emergencywp'), $mandatorName);
                default:
                    return __('Oops, there is unfortunately a technical error occurred.<br /><br /> ', 'emergencywp') . __('Please contact our support! <span class="error-code">[ErrorCode: ERR-JOB-0]</span> ', 'emergencywp');
            }
        }

        public static function getMessageText($status)
        {
            switch ($status) {
                case -99:
                    return __('Oops, there is unfortunately a technical error occurred.<br /><br />', 'emergencywp') . __('Please contact our support! <span class="error-code">[ErrorCode: ERR-JOB-99]</span>', 'emergencywp');
                    break;
                default:
            }

        }

        //public static function trustyResponseInTime( $status = null, $jobStatus = null ){
        public static function trustyResponse($status = null, $jobStatus = null, $inTime = false)
        {

            if (is_null($status) or is_null($jobStatus)) return 0;

            $aliveStatus = self::getAliveStatus();
            $jobSettings = self::getJobSettings();

            $responsesInTime = 0;

            foreach ($aliveStatus['trustyFeedback'][$jobStatus][$status] as $pId => $responseTime) {
                if ($inTime === true && (isset($aliveStatus['jobEmails'][$jobStatus]) && isset($jobSettings['live_status_' . $jobStatus . '_reactionTimeTrustees']))) {
                    // check timestamp of response. Is timestamp in response periode of finalHoldB
                    if ($responseTime <= ($aliveStatus['jobEmails'][$jobStatus] + $jobSettings['live_status_' . $jobStatus . '_reactionTimeTrustees'])) {
                        $responsesInTime++;
                    }
                } else $responsesInTime++;
            }

            return $responsesInTime;
        }

        public static function sendTestEmailToClient($blogId = null)
        {
            $mandatorData = emergencyWPAdmin::getMandatorData();
            $jobSettings = get_option('emergencyWP_job_settings');

            if ($mandatorData !== false) {

                $response = array('success' => false, 'error' => false, 'errorCode' => '');

                $aliveStatus = self::getAliveStatus();

                $structure = get_option('permalink_structure');
                $responseUrlStart = '?';
                if (strpos($structure, '?') !== false || empty($structure)) {
                    $responseUrlStart = '&amp;';
                }
                // fix get option - multisite
                $option_text = unserialize(get_option('emergencywp' . '_life_status_mail'));
                $responseUrl = get_permalink(get_option(EWP_initPluginVars::$pluginPages['job_response_options']['pageId'])) . $responseUrlStart . "type=" . md5('life_status') . "&amp;mandatorKey=" . $aliveStatus['mandatorKey'];
                $firstname = $mandatorData['firstName'];
                $lastname = $mandatorData['lastName'];
                $username = $firstname . ' ' . $lastname;

                $inviteSubject = $option_text['subject'];
                $inviteMessage = nl2br($option_text['message']);
                $inviteSubject = str_replace(__(EmailPlaceholdersTags::USER_FIRST_NAME, 'emergencywp'), $firstname, $inviteSubject);
                $inviteMessage = str_replace(__(EmailPlaceholdersTags::USER_LAST_NAME, 'emergencywp'), $lastname, $inviteMessage);
                $inviteMessage = str_replace(__(EmailPlaceholdersTags::USER_FULL_NAME, 'emergencywp'), $username, $inviteMessage);
                $inviteMessage = str_replace(__(EmailPlaceholdersTags::LIFE_CHECK_FREQUENCY, 'emergencywp'), ewp_settingtimesToDays($jobSettings['live_status_holdA_noFeedbackTime'], 'd', 4), $inviteMessage);
                $inviteMessage = str_replace(__(EmailPlaceholdersTags::LIFE_CHECK_TIME_FRAME, 'emergencywp'), ewp_settingtimesToDays($jobSettings['live_status_holdA_noFeedbackTime'], 'd', 4), $inviteMessage);
                $inviteMessage = str_replace(__(EmailPlaceholdersTags::USER_CONFIRMATION_URL, 'emergencywp'), $responseUrl, $inviteMessage); //EMERGENCY_WP_PLUGIN_URL, $inviteMessage);
                $inviteMessage = str_replace(__(EmailPlaceholdersTags::WEBSITE_URL, 'emergencywp'), EMERGENCY_WP_PLUGIN_URL, $inviteMessage);

                // call adminSystemEmail class
                emergencyWPSystemEmails::setStd();
                emergencyWPSystemEmails::setStd();
                emergencyWPSystemEmails::$postStatus = 'life_status';
                emergencyWPSystemEmails::$aliveInfo = UserStatus::ALIVE;
                emergencyWPSystemEmails::setEmail($mandatorData['email']);
                emergencyWPSystemEmails::setSubject('TEST-EMAIL: ');
                emergencyWPSystemEmails::$message = stripslashes($inviteMessage);
                emergencyWPSystemEmails::$message . "<br />";
                emergencyWPSystemEmails::sendEmail();

                if (emergencyWPSystemEmails::$sendStatus === true) {
                    echo 1;
                } else if (emergencyWPSystemEmails::$sendStatus === 'no-license') {
                    echo 'no-license';
                } else {
                    echo 0;
                }
            } else {
                echo -1;
            }
        }

        public static function getBlogId()
        {
            return self::$blogId;
        }

        public static function setBlogId($blogId)
        {
            if (!isset($blogId) || !is_numeric($blogId)) {
                return false;
            }

            self::$blogId = $blogId;
            return true;
        }

        public static function getBlogs($network_id = null)
        {
            $args = array(
                'network_id' => $network_id,
                'public' => null,
                'archived' => null,
                'mature' => null,
                'spam' => null,
                'deleted' => null,
                'limit' => 100,
                'offset' => 0,
            );
            return wp_get_sites($args);
        }

        public static function getAliveStatus()
        {
            global $wpdb;

            if (is_multisite()) {
                $aliveStatus = get_blog_option(self::$blogId, 'emergencyWP_alive_status');

                if (isset($aliveStatus['jobStatus'])) {
                    return $aliveStatus;
                } else {
                    EWP_initPluginVars::setAliveStatusVar(true);
                    $addAliveStatus = add_blog_option(self::$blogId, 'emergencyWP_alive_status', EWP_initPluginVars::$aliveStatus);

                    if (!$addAliveStatus) {
                        return false;
                    }
                    return EWP_initPluginVars::$aliveStatus;
                }
            } else {
                return get_option('emergencyWP_alive_status');
            }
        }

        public static function getJobSettings()
        {
            if (is_multisite()) {
                return get_blog_option(self::$blogId, 'emergencyWP_job_settings');
            } else {
                return get_option('emergencyWP_job_settings');
            }
        }

        public static function updateOption($key, $value)
        {
            if (is_multisite()) {
                update_blog_option(self::$blogId, $key, $value);
            } else {
                update_option($key, $value);
            }
        }

    }
}