<?php

class emergencyWPMessages
{
    static $postTypeSlug = "emergencywp_messages";
    static $className = "emergencyWPMessages";

    public function __construct()
    {
        add_action('plugins_loaded', array(&$this, 'init'));
        add_filter('map_meta_cap', array(&$this, 'emergencywp_messages_map_meta_cap'), 10, 4);
    }

    public function init()
    {
        add_action('add_meta_boxes', array(&$this, 'my_remove_wp_seo_meta_box'), 100);
    }

    static function my_remove_wp_seo_meta_box()
    {
        remove_meta_box('wpseo_meta', self::$postTypeSlug, 'normal');
    }

    public static function admin_menu()
    {
        $minCapability = emergencyWPAdmin::getMinCapability();
        add_submenu_page(
            'emergencywp',
            __('Messages', 'emergencywp'),
            __('Messages', 'emergencywp'),
            $minCapability,
            'edit.php?post_type=emergencywp_messages',
            null
        );
    }

    public function edit_entry()
    {
        global $post;
        if (isset($_POST) && count($_POST) > 0) {
            if (isset($_POST['publish'])) {
                if (isset($_GET['new'])) {
                    // Create post object
                    $my_post = array(
                        'post_type' => 'emergencywp_messages'
                    );

                    // Insert the post into the database
                    $id = wp_insert_post($my_post);
                    $saved_id = emergencyWPMessages::saveCustomePostTypeMetaBox($id);

                    if ($saved_id != false) {
                        wp_redirect('admin.php?page=emergencywp_messages');
                    }
                } else {
                    $saved_id = emergencyWPMessages::saveCustomePostTypeMetaBox(intval($_GET['ID']));
                }
            }
        }
    }

    public static function initPostType()
    {
        self::customePostType();
        add_filter('manage_edit-' . self::$postTypeSlug . '_columns', array(self::$className, 'postTypeColumns'));
        add_action('manage_' . self::$postTypeSlug . '_posts_custom_column', array(self::$className, 'managePostTypeColumns'), 10, 2);
        add_action('admin_init', array(self::$className, 'addPostTypeMetaBox'));
        add_action('post_updated', array(self::$className, 'saveCustomePostTypeMetaBox'), 10, 2);

        add_filter('enter_title_here', array(self::$className, 'ewp_change_title_text'));
        add_action('emergencywp_additional_menus', array(self::$className, 'admin_menu'), 20);

        add_filter('get_edit_post_link', array(self::$className, 'append_query_string'), 10, 2);
        add_filter('get_add_post_link', array(self::$className, 'append_query_string'), 10, 2);

        add_action('add_meta_boxes', array(self::$className, 'my_remove_wp_seo_meta_box'), 100);
    }

    static function append_query_string($url, $post)
    {
        if ('emergencywp_messages' == get_post_type($post)) {
            return add_query_arg(array('parent' => 'emergencywp', 'post_type'=>self::$postTypeSlug), $url);
        }
        return $url;
    }


    public static function ewp_change_title_text($title)
    {
        $screen = get_current_screen();

        if ('emergencywp_messages' == $screen->post_type) {
            $title = __('Enter subject here', 'emergencywp');
        }

        return $title;
    }

    public static function postTypeColumns($postTypeColumns)
    {
        // declare message Post Type Columns
        $new_columns['cb'] = '<label class="screen-reader-text" for="cb-select-all-1">' . __('select all ', 'emergencywp') . '</label><input id="cb-select-all-1" type="checkbox">';
        $new_columns['title'] = __('Title', 'emergencywp');
        $new_columns['contacts'] = __('Recipient ', 'emergencywp');

        $args = array(
            'posts_per_page' => -1,
            'offset' => 0,

            'include' => '',
            'exclude' => '',
            'meta_key' => '',
            'meta_value' => '',
            'post_type' => 'emergencywp_messages',
            'post_mime_type' => '',
            'post_parent' => '',
            'post_status' => 'any',
            'suppress_filters' => true
        );
        $messages = emergencyWPAdmin::getWpPost($args);

        if (count($messages)) {
            foreach ($messages as $message) {
                if (emergencyWPMessages::messageHasDeliveryConditionValues($message->ID)) {
                    $new_columns['delivery_conditions'] = __('Delivery Conditions', 'emergencywp-delivery-conditions');
                    break;
                }
            }
        }
        $new_columns = apply_filters('manage_emergencywp_messages_posts_columns', $new_columns);
        return $new_columns;
    }

    public static function managePostTypeColumns($column_name, $id)
    {
        global $wpdb;
        switch ($column_name) {
            case 'contacts':
                $c = unserialize(get_post_meta($id, self::$postTypeSlug . "_contacts", true));
                if (is_array($c)) {
                    foreach ($c as $cId => $v) {
                        $firstName = get_post_meta($cId, emergencyWPContacts::$postTypeSlug . "_firstName", true);
                        $lastName = get_post_meta($cId, emergencyWPContacts::$postTypeSlug . "_lastName", true);
                        echo esc_html($firstName . " " . $lastName) . "<br />";
                    }
                } else {
                    echo __('no contacts (!) ', 'emergencywp');
                }
                break;
            case 'delivery_conditions':
                if (emergencyWPMessages::messageHasDeliveryConditionValues($id) && !defined('EMERGENCY_WP_DELIVERY_CONDITIONS_PLUGIN_NAME')) {
                    echo '<div class="tooltip">'.__('This message has conditions setup so will not be sent', 'emergencywp').'
                            <span class="tooltiptext">'.__('This message has conditions setup, but EmergencyWP Conditions Addon is deactivated. Message will not be sent', 'emergencywp').'</span>
                        </div>';
                }
                break;
            case 'attachments':
                $messages = emergencyWPAdmin::getWpPost($args);

                if (count($messages)) {
                    foreach ($messages as $message) {
                        if (emergencyWPMessages::messageHasDeliveryConditionValues($message->ID)) {
                            $new_columns['delivery_conditions'] = __('Delivery Conditions', 'emergencywp');
                            break;
                        }
                    }
                }
                break;
            default:
                break;
        } // end switch
    }

    public static function addPostTypeMetaBox()
    {
        add_meta_box(
            self::$postTypeSlug . '_meta_box_contacts',
            __('Contacts ', 'emergencywp'), //__('Your Message', 'emergencywp'),
            array(self::$className, 'displayPostTypeMetaBox'),
            self::$postTypeSlug, 'normal', 'high'
        );
        add_meta_box('emergencywp_messages_submitdiv', __('Save', 'emergencywp_messages'), array(
            self::$className,
            'emergencywp_messages_submit'
        ), 'emergencywp_messages', 'side', 'high');
    }

    public static function customePostType()
    {
        global $wp_roles;
        register_post_type(self::$postTypeSlug,
            array(
                "public" => true,
                "publicly_queryable" => false,
                "menu_icon" => "dashicons-email-alt",
                'capability_type' => 'emergencywp_messages',
                'capabilities' => array(
                    'publish_posts' => 'publish_emergencywp_messages',
                    'edit_posts' => 'edit_emergencywp_messages',
                    'edit_others_posts' => 'edit_others_emergencywp_messages',
                    'delete_posts' => 'delete_emergencywp_messages',
                    'delete_others_posts' => 'delete_others_emergencywp_messages',
                    'read_private_posts' => 'read_private_emergencywp_messages',
                    'edit_post' => 'edit_emergencywp_message',
                    'delete_post' => 'delete_emergencywp_message',
                    'read_post' => 'read_emergencywp_message',
                ),
                "labels" => array(
                    "name" => __('Messages', 'emergencywp'),
                    "singular_name" => __('Message', 'emergencywp'),
                    "add_new" => __('Add New', 'emergencywp'),
                    "add_new_item" => __('Add New Message', 'emergencywp'),
                    "edit" => __('Edit', 'emergencywp'),
                    "edit_item" => __('Edit Message', 'emergencywp'),
                    "new_item" => __('New Message', 'emergencywp'),
                    "view" => __('View Message', 'emergencywp'),
                    "view_item" => __('View Message', 'emergencywp'),
                    "search_items" => __('Search Messages', 'emergencywp'),
                    "not_found" => __('No Messages Found', 'emergencywp'),
                    "not_found_in_trash" => __('No Messages Found in trash', 'emergencywp'),
                    "parent" => __(self::$postTypeSlug),
                ),
                "show_in_menu" => false,
                "menu_position" => 100,
                "supports" => array(
                    'title',
                    'editor',
                    "custom_fields"
                ),
            )
        );

        $role = 'administrator';
        $wp_roles->add_cap($role, 'publish_emergencywp_messages');
        $wp_roles->add_cap($role, 'edit_emergencywp_messages');
        $wp_roles->add_cap($role, 'edit_others_emergencywp_messages');
        $wp_roles->add_cap($role, 'delete_emergencywp_messages');
        $wp_roles->add_cap($role, 'delete_others_emergencywp_messages');
        $wp_roles->add_cap($role, 'edit_emergencywp_message');
        $wp_roles->add_cap($role, 'delete_emergencywp_message');
        $wp_roles->add_cap($role, 'read_emergencywp_message');
    }

    public static function displayPostTypeMetaBox($emergencyWP_message)
    {
        global $post;

        $contacts = unserialize(get_post_meta($emergencyWP_message->ID, self::$postTypeSlug . '_contacts', true));
        $sendDateType = unserialize(get_post_meta($emergencyWP_message->ID, self::$postTypeSlug . '_sendDateType', true));
        $uploadedFiles = unserialize(get_post_meta($emergencyWP_message->ID, self::$postTypeSlug . '_uploadedFiles', true));

        ?>
        <div id="messages_contacts" class="ewp_meta_box">
            <div class="ewp-notice -error ewp-error-message" style="display: none">
                <p><?php echo __('You must select at least one contact!', 'emergencywp-vault'); ?></p>
            </div>
            <input type="hidden" name="custom_meta_box_nonce"
                   value="<?php echo wp_create_nonce('class.emergencyWPMessages.details'); ?>"/>

            <div class="margin-top-bottom-10 mm_recipients">
                <div class="input-control">
                    <ul class="recipients-list-4-cols">
                        <?php
                        $args = array(
                            'post_type' => emergencyWPContacts::$postTypeSlug,
                            'post_status' => 'publish',
                            'posts_per_page' => -1,
                            //'caller_get_posts'=> 1 // verwende hier ignore_sticky_posts ... falls überhaupt nötig!
                        );

                        $my_query = null;
                        $my_query = new WP_Query($args);
                        if ($my_query->have_posts()) {
                            while ($my_query->have_posts()) : $my_query->the_post();
                                $firstName = get_post_meta(get_the_id(), emergencyWPContacts::$postTypeSlug . "_firstName", true);
                                $lastName = get_post_meta(get_the_id(), emergencyWPContacts::$postTypeSlug . "_lastName", true);
                                $thumbEmail = get_post_meta(get_the_id(), emergencyWPContacts::$postTypeSlug . "_email", true);
                                $checked = '';
                                if (is_array($contacts)) {
                                    if (array_key_exists(get_the_ID(), $contacts)) {
                                        $checked = ' checked="checked" ';
                                    }
                                }
                                $defaultAvatar = EMERGENCY_WP_PLUGIN_URL . 'assets/images/user01.gif';
                                echo '<li>
                                    <input type="checkbox" name="' . esc_attr(self::$postTypeSlug) . '_contacts[' . get_the_id() . ']" value="1" ' . esc_attr($checked) . ' /> 
                                    <img title="" src = "https://2.gravatar.com/avatar/' . md5(strtolower(trim($thumbEmail))) . '?s=400&amp;d=' . urlencode($defaultAvatar) . '&amp;r=g" width="80" />
								' . esc_attr($firstName) . ' ' . esc_attr($lastName) . '
								</li>';
                            endwhile;
                        } else {
                            echo '<li><label>' . __('No contacts available', 'emergencywp') . '</label></li>';
                        }
                        wp_reset_query();  // Restore global post data stomped by the_post().
                        ?>
                    </ul>
                </div>
            </div>
        </div>


        <?php
    }

    public static function saveCustomePostTypeMetaBox($post_id)
    {
        global $post;

        // verify nonce
        if (!wp_verify_nonce(@$_POST['custom_meta_box_nonce'], 'class.emergencyWPMessages.details')) {
            return $post_id;
        }

        // check autosave
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return $post_id;
        }

        // check permissions
        if (!current_user_can(emergencyWPAdmin::getMinCapability())) {
            return $post_id;
        }

        $e = 0;

        // title
        if (strlen(sanitize_text_field($_POST['post_title'])) === 0) {
            emergencyWPAdmin::setAdminNotice('error', 'messages', __('You have not specified a subject.', 'emergencywp'));
            $e++;
        }
        // Description
        if (strlen(sanitize_text_field($_POST['content'])) === 0) {
            emergencyWPAdmin::setAdminNotice('error', 'messages', __('You have not specified a message.', 'emergencywp'));
            $e++;
        }
        // Contacts
        if (is_array(sanitize_text_field($_POST[self::$postTypeSlug . '_contacts'])) && count(sanitize_text_field($_POST[self::$postTypeSlug . '_contacts'])) == 0) {
            emergencyWPAdmin::setAdminNotice('error', 'messages', __('You have not specified contacts.', 'emergencywp'));
            $e++;
        }


        self::saveMetaBoxData(self::$postTypeSlug . '_subject', $post_id);
        self::saveMetaBoxData(self::$postTypeSlug . '_message', $post_id);
        self::saveMetaBoxData(self::$postTypeSlug . '_contacts', $post_id);

        if ($e > 0) {

            return $post_id;

        } else {
            if ($post->post_status === 'auto-draft') {
                emergencyWPAdmin::setAdminNotice('updated', 'messages', __('A new message has been created', 'emergencywp'));
            } else {
                emergencyWPAdmin::setAdminNotice('updated', 'messages', __('The message was updated successfully.', 'emergencywp'));
            }
        }
    }

    private static function saveMetaBoxData($post_meta_key, $pId)
    {
        if (!is_numeric($pId)) {
            return false;
        }

	    if(is_array($_POST[$post_meta_key] )) {
		    $tags = isset( $_POST[$post_meta_key] ) ? (array) $_POST[$post_meta_key] : array();
		    $meta_value_new = array_map('esc_attr', $tags);
	    } else {
		    $meta_value_new = sanitize_text_field($_POST[$post_meta_key]);
	    }
        $meta_value_old = get_post_meta($pId, $post_meta_key, true);
        if (is_array($meta_value_new)) {
            if (count($meta_value_new) == 0) {
                delete_post_meta($pId, $post_meta_key, serialize($meta_value_new));
            } else {
                update_post_meta($pId, $post_meta_key, serialize($meta_value_new));
            }
        } else {
            if ($meta_value_new && $meta_value_new != $meta_value_old) {
                update_post_meta($pId, $post_meta_key, $meta_value_new);
            } elseif ('' == $meta_value_new && $meta_value_old) {
                delete_post_meta($pId, $post_meta_key, $meta_value_new);
            }
        }
    }

    public static function emergencywp_messages_submit($post)
    {
        global $action;
        $post_type = $post->post_type;
        $post_type_object = get_post_type_object($post_type);
        include EMERGENCY_WP_PLUGIN_DIR . 'views/messages/submit.php';
    }

    public static function messageHasDeliveryConditionValues($messageID)
    {
        if (defined('EMERGENCY_WP_DELIVERY_CONDITIONS_PLUGIN_NAME')) {
            $deliveryFieldPrefix = EMERGENCY_WP_DELIVERY_CONDITIONS_PLUGIN_NAME;
        } else {
            $deliveryFieldPrefix = 'emergencywp-delivery-conditions';
        }

        $relative_delay_enabled = get_post_meta($messageID, $deliveryFieldPrefix . '_relative_enabled', true);
        $absolute_delay_enabled = get_post_meta($messageID, $deliveryFieldPrefix . '_absolute_enabled', true);
        $recurring_delay_enabled = get_post_meta($messageID, $deliveryFieldPrefix . '_recurring_enabled', true);

        if ($relative_delay_enabled == '1' || $absolute_delay_enabled == '1' || $recurring_delay_enabled == '1') {
            return true;
        } else {
            return false;
        }
    }

    public static function messageReadyToSendBasedOnDeliveryConditionValues($messageID, $aliveStatus, $firstRun = true, $debugMode = 0)
    {
        include_once(ABSPATH . 'wp-admin/includes/plugin.php');
        if (is_plugin_active('emergencywp-delivery-conditions/emergencywp-delivery-conditions.php') && defined('EMERGENCY_WP_DELIVERY_CONDITIONS_PLUGIN_NAME')) {
            $deliveryFieldPrefix = EMERGENCY_WP_DELIVERY_CONDITIONS_PLUGIN_NAME;

            $relative_delay_enabled = get_post_meta($messageID, $deliveryFieldPrefix . '_relative_enabled', true);
            $absolute_delay_enabled = get_post_meta($messageID, $deliveryFieldPrefix . '_absolute_enabled', true);
            $recurring_delay_enabled = get_post_meta($messageID, $deliveryFieldPrefix . '_recurring_enabled', true);

            $deliveryConditionValue = get_post_meta($messageID, $deliveryFieldPrefix . '_value', true);
            $deliveryConditionUnit = get_post_meta($messageID, $deliveryFieldPrefix . '_unit', true);

            $pronouncedDeadTimestamp = $aliveStatus['jobEmails']['dead'];

            $UTC = new DateTimeZone("UTC");
            $pronouncedDeadDate = new DateTime();
            $pronouncedDeadDate->setTimestamp($pronouncedDeadTimestamp);
            $pronouncedDeadDate->setTimezone($UTC);

            $pronouncedDeadRelativeDate = new DateTime();

            $dateFormat = emergencyWPAdmin::getDateFormat();
            if ($relative_delay_enabled == '1') {
                if($debugMode){
                    echo '$relative_delay_enabled ';
                    print_r('<br>');
                }
                if (empty($deliveryConditionValue) || empty($deliveryConditionUnit) || $deliveryConditionValue == false || $deliveryConditionUnit == false) {
                    return true;
                }

                $pronouncedDeadRelativeDate = clone $pronouncedDeadDate;

                if ($deliveryConditionValue == 1) {
                    $deliveryConditionUnit = rtrim($deliveryConditionUnit, 's');
                }

                if($debugMode){
                    print_r($deliveryConditionValue);
                    print_r($deliveryConditionUnit);
                    print_r('<br>');
                }
                $pronouncedDeadRelativeDate->modify("+{$deliveryConditionValue} {$deliveryConditionUnit}");

                if($debugMode){
                    print_r('pronouncedDeadRelativeDate');
                    print_r($pronouncedDeadRelativeDate);
                    print_r('<br>');
                }

            } else if ($absolute_delay_enabled == '1') {
                if($debugMode){
                    echo '$absolute_delay_enabled ';
                    print_r('<br>');
                }
                $absolute_date = get_post_meta($messageID, $deliveryFieldPrefix . '_absolute_date', true);
                $absolute_value_timestamp = get_post_meta($messageID, $deliveryFieldPrefix . '_absolute_date_timestamp', true);
                if (empty($absolute_date) || $absolute_date == false || empty($absolute_value_timestamp) || $absolute_value_timestamp == false) {
                    return false;
                }

                if($debugMode){
                    print_r($absolute_date);
                    print_r($absolute_value_timestamp);
                    print_r('<br>');
                }
                $UTC = new DateTimeZone("UTC");
                $pronouncedDeadRelativeDate = date_create_from_format(emergencyWPAdmin::getDateFormat(), $absolute_date, $UTC);
                if(!is_object($pronouncedDeadRelativeDate)){
                    $pronouncedDeadRelativeDate = new DateTime();
                    $pronouncedDeadRelativeDate->setTimezone($UTC);
                    $pronouncedDeadRelativeDate->setTimestamp($absolute_value_timestamp);
                }

                $absolute_auto_send_enabled = get_post_meta($messageID, $deliveryFieldPrefix . '_absolute_auto_send_enabled', true);
                if($absolute_auto_send_enabled == '0' && $pronouncedDeadDate < $pronouncedDeadRelativeDate) {
                    return false;
                }
            } else if ($recurring_delay_enabled == '1') {
                if($debugMode){
                    echo '$recurring_delay_enabled ';
                    print_r('<br>');
                }
                $recurring_value = get_post_meta($messageID, $deliveryFieldPrefix . '_recurring_date', true);
                $recurring_value_timestamp = get_post_meta($messageID, $deliveryFieldPrefix . '_recurring_date_timestamp', true);

                if (empty($recurring_value) || $recurring_value == false || empty($recurring_value_timestamp) || $recurring_value_timestamp == false) {
                    return false;
                }

                if($debugMode){
                    print_r($recurring_value);
                    print_r($recurring_value_timestamp);
                    print_r('<br>');
                }

                $pronouncedDeadRelativeDate= date_create_from_format( emergencyWPAdmin::trimYearFromDateFormat(emergencyWPAdmin::getDateFormat()), $recurring_value, $UTC);
                if(!is_object($pronouncedDeadRelativeDate)){
                    $pronouncedDeadRelativeDate = new DateTime();
                    $pronouncedDeadRelativeDate->setTimezone($UTC);
                    $pronouncedDeadRelativeDate->setTimestamp($recurring_value_timestamp);
                }

                $recurring_auto_send_enabled = get_post_meta($messageID, $deliveryFieldPrefix . '_recurring_auto_send_enabled', true);
                if($recurring_auto_send_enabled == '0' && $pronouncedDeadDate < $pronouncedDeadRelativeDate) {
                    return false;
                }
            }

            $date_now = new DateTime();
            if($debugMode){
                print_r($date_now);
                var_dump($pronouncedDeadRelativeDate);
                print_r('<br>');
            }

            if(!is_object($pronouncedDeadRelativeDate)) {
                return false;
            }
            if ($date_now < $pronouncedDeadRelativeDate ) {
                return false;
            } else {
                return true;
            }
        } else if (!is_plugin_active('emergencywp-delivery-conditions/emergencywp-delivery-conditions.php') && $firstRun) {
            return true;
        } else {
            return false;
        }
    }

    public static function messageReadyToSendNotificationBasedOnDeliveryConditionValues($messageID, $aliveStatus)
    {
        include_once(ABSPATH . 'wp-admin/includes/plugin.php');
        if (is_plugin_active('emergencywp-delivery-conditions/emergencywp-delivery-conditions.php') && defined('EMERGENCY_WP_DELIVERY_CONDITIONS_PLUGIN_NAME')) {
            $deliveryFieldPrefix = EMERGENCY_WP_DELIVERY_CONDITIONS_PLUGIN_NAME;

            $relative_delay_enabled = get_post_meta($messageID, $deliveryFieldPrefix . '_relative_enabled', true);
            $absolute_delay_enabled = get_post_meta($messageID, $deliveryFieldPrefix . '_absolute_enabled', true);
            $recurring_delay_enabled = get_post_meta($messageID, $deliveryFieldPrefix . '_recurring_enabled', true);

            $UTC = new DateTimeZone("UTC");
            $pronouncedDeadRelativeDate = new DateTime();

            $dateFormat = emergencyWPAdmin::getDateFormat();
            if ($relative_delay_enabled == '1') {
                return false;
            } else if ($absolute_delay_enabled == '1') {
                $absolute_date = get_post_meta($messageID, $deliveryFieldPrefix . '_absolute_date', true);
                $absolute_value_timestamp = get_post_meta($messageID, $deliveryFieldPrefix . '_absolute_date_timestamp', true);
                if (empty($absolute_date) || $absolute_date == false || empty($absolute_value_timestamp) || $absolute_value_timestamp == false) {
                    return false;
                }

                $UTC = new DateTimeZone("UTC");
                $pronouncedDeadRelativeDate = date_create_from_format(emergencyWPAdmin::getDateFormat(), $absolute_date, $UTC);
                if(!is_object($pronouncedDeadRelativeDate)){
                    $pronouncedDeadRelativeDate = new DateTime();
                    $pronouncedDeadRelativeDate->setTimezone($UTC);
                    $pronouncedDeadRelativeDate->setTimestamp($absolute_value_timestamp);
                }
            } else if ($recurring_delay_enabled == '1') {
                $recurring_value = get_post_meta($messageID, $deliveryFieldPrefix . '_recurring_date', true);
                $recurring_value_timestamp = get_post_meta($messageID, $deliveryFieldPrefix . '_recurring_date_timestamp', true);

                if (empty($recurring_value) || $recurring_value == false || empty($recurring_value_timestamp) || $recurring_value_timestamp == false) {
                    return false;
                }

                $pronouncedDeadRelativeDate= date_create_from_format( emergencyWPAdmin::trimYearFromDateFormat(emergencyWPAdmin::getDateFormat()), $recurring_value, $UTC);
                if(!is_object($pronouncedDeadRelativeDate)){
                    $pronouncedDeadRelativeDate = new DateTime();
                    $pronouncedDeadRelativeDate->setTimezone($UTC);
                    $pronouncedDeadRelativeDate->setTimestamp($recurring_value_timestamp);
                }
            }

            $date_now = new DateTime();
            if ($date_now > $pronouncedDeadRelativeDate ) {
                return true;
            } else {
                return false;
            }
        } else {
            return false;
        }
    }

    function emergencywp_messages_map_meta_cap($caps, $cap, $user_id, $args)
    {
        $minCapability = emergencyWPAdmin::getMinCapability();
        /* If editing, deleting, or reading a movie, get the post and post type object. */
        if ('edit_emergencywp_messages' == $cap || 'delete_emergencywp_messages' == $cap || 'read_emergencywp_messages' == $cap) {
            /* Set an empty array for the caps. */
            $caps = array();
        }
        /* If editing a movie, assign the required capability. */
        if ('edit_emergencywp_messages' == $cap) {
            if (current_user_can($minCapability))
                $caps[] = 'edit_emergencywp_messages';
        } /* If deleting a movie, assign the required capability. */
        elseif ('edit_emergencywp_message' == $cap) {
            if (current_user_can($minCapability))
                $caps[] = 'edit_emergencywp_message';
        } elseif ('delete_emergencywp_messages' == $cap) {
            if (current_user_can($minCapability))
                $caps[] = 'delete_emergencywp_messages';
        } /* If reading a private movie, assign the required capability. */
        elseif ('read_emergencywp_messages' == $cap) {
            if (current_user_can($minCapability))
                $caps[] = 'read_emergencywp_messages';
        }

        if (isset($_GET['post_type']) && sanitize_text_field($_GET['post_type']) == 'emergencywp_messages') {
            $caps[] = 'edit_emergencywp_message';
        }
        /* Return the capabilities required by the user. */
        return $caps;
    }
}

?>