<?php

function ewp_mysqlDate2timestamp($date, $systemTime = true)
{
    $d = explode(' ', $date);
    $t = explode(':', $d[1]);
    if (count($t) == 2) $t[2] = '00';
    $dd = explode('-', $d[0]);
    $utcTimestamp = mktime($t[0], $t[1], $t[2], $dd[1], $dd[2], $dd[0]);
    if ($systemTime === true) {
        return ($utcTimestamp + (emergencyWPAdmin::$systemGmtOffset * 3600));
    }
    return $utcTimestamp;
}

function ewp_mysqlDate2Date($date = null, $time = false, $systemTime = true)
{
    if (is_null($date)) return false;
    $timestamp = ewp_mysqlDate2timestamp($date, $systemTime);
    if ($time === 1) return date(emergencyWPAdmin::getFullDateFormat(), $timestamp);
    else return date(emergencyWPAdmin::getDateFormat(), $timestamp);
}

function ewp_utcTimestampToSystemTimestamp($utcTimestamp)
{
    return ($utcTimestamp + (emergencyWPAdmin::$systemGmtOffset * 3600));
}

function ewp_systemUtcTimestamp($mysqlDate)
{
    return ewp_utcTimestampToSystemTimestamp(ewp_mysqlDate2timestamp($mysqlDate));
}

function ewp_systemTimestampToDate($timestamp, $time)
{
    return ewp_systemDate(date('Y.m.d H:i:s', $timestamp), $time);
}

function ewp_systemDate($mysqlDate = null, $time = null)
{
    if (is_null($mysqlDate) || is_null($time)) {
        return false;
    }

    $systemTimestamp = ewp_utcTimestampToSystemTimestamp(ewp_mysqlDate2timestamp($mysqlDate));
    $dateFormat = 'd.m.Y';
    if ($time === 1) {
        $dateFormat = 'd.m.Y H:i:s';
    }

    return date($dateFormat, $systemTimestamp);
}

function ewp_getPassThroughKey()
{
    return md5(uniqid(rand(), TRUE));
}

function ewp_settingtimesToDays($timesec = null, $setToTime = 'd', $decimalPlaces = 0)
{
    if (is_null(@$timesec) or !is_numeric(@$timesec)) return "no time given! (EC: 4402)";

    switch ($setToTime) {
        // minute
        case 'm':
            $multiplier = 60;
            break;
        // hour
        case 'h':
            $multiplier = 60 * 60;
            break;
        // days
        case 'd':
            $t = $timesec / 86400;
            $time = 0;
            if ($t < 1) {
                $time = ($t * 24 * 60) . ' ' . __('Minutes', 'emergencywp');
            } else if ($t == 1) {
                $time = __('24 hours', 'emergencywp');
            } else if ($t <= 30) {
                $time = $t . ' ' . __('days', 'emergencywp');
            } else if ($t > 30) {
                $time = ($t / 30.44);
                if ($time === 1) {
                    $time = __('1 Month', 'emergencywp');
                } else {
                    $time = number_format($time, 0, '', '') . ' ' . __('Months', 'emergencywp');
                }
            }
            return $time;
            break;
        default:
            $multiplier = 1;
    }
    return number_format(($timesec / $multiplier), $decimalPlaces, '.', ',');
}

/**
 *
 *
 * @param unknown $subclass (optional)
 * @return unknown
 */
function emergencyWP($subclass = null)
{
    global $emergencyWP;

    $args = func_get_args();
    $subclass = array_shift($args);

    if (is_null($subclass)) {
        return $emergencyWP;
    }

    return call_user_func_array(array($emergencyWP, $subclass), $args);
}

/**
 *
 *
 * @param unknown $option
 * @param unknown $fallback (optional)
 * @param unknown $global (optional)
 * @return unknown
 */
function emergencywp_option($option, $fallback = null, $global = false)
{
    global $emergencywp_options;
    if(!is_array($emergencywp_options)) {
        $emergencywp_options = wp_parse_args($option, $emergencywp_options);
    }

    $value = isset($emergencywp_options[$option]) ? $emergencywp_options[$option] : $fallback;

    $value = apply_filters('emergencywp_options', $value, $option, $fallback, $global);

    if (is_string($value)) {
        $value = apply_filters('emergencywp_options_' . $option, $value, $fallback, $global);
    }
    return $value;
}

/**
 *
 *
 * @param string $option
 * @param unknown $value
 * @param unknown $global (optional)
 * @return unknown
 */
function emergencywp_update_option($option, $value, $global = false)
{
    global $emergencywp_options;
    $emergencywp_options = wp_parse_args($option, $emergencywp_options);
    $emergencywp_options[$option] = apply_filters('emergencywp_update_option_' . $option, $value, $global);

    $result = ewp_update_option('emergencywp_options', $emergencywp_options, $global);
    $result = apply_filters('emergencywp_update_option', $emergencywp_options, $global);

    return $result;
}

function ewp_get_option($option, $fallback = null, $global = false)
{
    $value = get_option($option);

    $value = apply_filters('ewp_get_option', $value, $option, $global, $fallback);
    if (is_string($value)) {
        $value = apply_filters('ewp_get_option_' . $value, $value, $option, $global, $fallback);
    }

    return $value;
}

function ewp_update_option($option, $value, $global = false)
{
    $valueResult = update_option($option, $value);
    $valueResult = apply_filters('ewp_update_option', $valueResult, $option, $value, $global);
    $valueResult = apply_filters('ewp_update_option_' . $valueResult, $option, $value, $global);
    return $valueResult;
}

function ewp_delete_option($option, $global = false)
{
    $valueResult = delete_option($option);
    $valueResult = apply_filters('ewp_delete_option', $valueResult, $option, $global);
    $valueResult = apply_filters('ewp_delete_option_' . $valueResult, $option, $global);
    return $valueResult;
}

/**
 *
 *
 * @return unknown
 */
function emergencywp_get_ip()
{

    $ip = apply_filters('mymail_get_ip', apply_filters('emergencywp_get_ip', null));

    if (!is_null($ip)) {
        return $ip;
    }

    $ip = '';
    foreach (array('HTTP_CLIENT_IP', 'HTTP_X_REAL_IP', 'HTTP_X_FORWARDED_FOR', 'HTTP_X_FORWARDED', 'HTTP_X_CLUSTER_CLIENT_IP', 'HTTP_FORWARDED_FOR', 'HTTP_FORWARDED', 'REMOTE_ADDR') as $key) {
        if (isset($_SERVER[$key])) {
            foreach (explode(',', $_SERVER[$key]) as $ip) {
                $ip = trim($ip);
                if (emergencywp_validate_ip($ip)) {
                    return $ip;
                }
            }
        }
    }
    return $ip;
}

/**
 *
 *
 * @param unknown $ip
 * @return unknown
 */
function emergencywp_validate_ip($ip)
{

    if (strtolower($ip) === 'unknown') {
        return false;
    }

    return filter_var($ip, FILTER_VALIDATE_IP);
}

function ewp_isCurl(){
    return function_exists('curl_version');
}

function ewp_remove_notice_now($key)
{
    $ewpNotices = get_option('emergencyWP_notices');
    if (isset($ewpNotices[$key])) {

        unset($ewpNotices[$key]);

        return update_option('emergencyWP_notices', $ewpNotices);
    }

    return false;
}

function ewp_remove_notice($key)
{

    $ewpNotices = get_option('emergencyWP_notices');
    if (isset($ewpNotices[$key])) {

        do_action('emergencywp_remove_notice_' . $key);
        unset($ewpNotices[$key]);

        return update_option('emergencyWP_notices', $ewpNotices);
    }

    return false;
}

function ewp_cmp_by_email_id($a, $b)
{
    return $a["id"] - $b["id"];
}

?>
